
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class ActTypeModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(ActTypeModel, self).__init__(ActType, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class ActType:

    def __init__(self):
        super(ActType, self).__init__()
        self.id = 0  # id
        self.type_name = ""  # 类型名称
        self.act_title = ""  # 活动标题
        self.act_tag = ""  # 活动标签（逗号分隔多个）
        self.act_img = ""  # 活动图
        self.currency_type = 0  # 抽奖货币类型（0无1次数2积分3价格档位4抽奖码）
        self.task_currency_type = ""  # 任务货币类型（字典数组）
        self.marketing_id = ""  # 营销方案id列表（逗号分隔多个id）
        self.experience_img = ""  # 体验码二维码图
        self.play_process = ""  # 玩法流程
        self.applicable_behavior = ""  # 适用行为
        self.market_function = ""  # 营销功能
        self.skill_case = ""  # 活动设置技巧案例
        self.type_desc = ""  # 类型描述
        self.share_desc = ""  # 分享内容（json）
        self.rule_desc = ""  # 规则内容（json）
        self.integral_rule = ""  # 积分规则（json）
        self.sort_index = 0  # 排序
        self.is_release = 0  # 是否发布（1是0否）
        self.release_date = "1900-01-01 00:00:00"  # 发布时间
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间

    @classmethod
    def get_field_list(self):
        return ['id', 'type_name', 'act_title', 'act_tag', 'act_img', 'currency_type', 'task_currency_type', 'marketing_id', 'experience_img', 'play_process', 'applicable_behavior', 'market_function', 'skill_case', 'type_desc', 'share_desc', 'rule_desc', 'integral_rule', 'sort_index', 'is_release', 'release_date', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "act_type_tb"
    



#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class VersionInfoModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(VersionInfoModel, self).__init__(VersionInfo, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class VersionInfo:

    def __init__(self):
        super(VersionInfo, self).__init__()
        self.id = 0  # id
        self.type_id = 0  # 类型（1消费者端2千牛端）
        self.version_number = ""  # 更新版本号
        self.is_force_update = 0  # 是个强制更新客户端版本（1是0否）
        self.content = ""  # 更新内容
        self.is_release = 0  # 是否发布（1是0否）
        self.release_date = "1900-01-01 00:00:00"  # 发布时间
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.modify_date = "1900-01-01 00:00:00"  # 更新时间

    @classmethod
    def get_field_list(self):
        return ['id', 'type_id', 'version_number', 'is_force_update', 'content', 'is_release', 'release_date', 'create_date', 'modify_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "version_info_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-11-20 16:16:22
:LastEditTime: 2020-12-25 11:12:49
:LastEditors: HuangJingCan
:description: appinfo相关
"""
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.db_models.app.app_info_model import *


class GetAppExpireHandler(SevenBaseHandler):
    """
    :description: 获取小程序是否过期未续费
    """
    def get_async(self):
        """
        :description: 获取小程序是否过期未续费
        :return info
        :last_editors: HuangJianYi
        """
        app_id = self.get_taobao_param().source_app_id
        now_date = self.get_now_datetime()

        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=[app_id])
        if not app_info:
            return self.reponse_json_error("NoAct", "对不起，找不到该小程序")

        info = {}
        if app_info.expiration_date == "1900-01-01 00:00:00":
            info["is_expire"] = 0
        elif TimeHelper.format_time_to_datetime(now_date) > TimeHelper.format_time_to_datetime(app_info.expiration_date):
            info["is_expire"] = 1
        else:
            info["is_expire"] = 0

        return self.reponse_json_success(info)


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-19 11:33:16
:LastEditTime: 2021-06-02 18:10:42
:LastEditors: HuangJingCan
:description: 任务处理
"""
from seven_cloudapp.handlers.task_base import *

from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.behavior_model import *
from seven_cloudapp.models.db_models.coin.coin_order_model import *
from seven_cloudapp.models.db_models.pay.pay_order_model import *
from seven_cloudapp.models.db_models.user.user_info_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.task.task_info_model import *
from seven_cloudapp.models.db_models.task.task_count_model import *
from seven_cloudapp.models.db_models.lottery.lottery_value_log_model import *
from seven_cloudapp.models.db_models.invite.invite_log_model import *
from seven_cloudapp.models.db_models.collect.collect_log_model import *
from seven_cloudapp.models.db_models.browse.browse_log_model import *
from seven_cloudapp.models.db_models.prize.prize_roster_model import *


class TaskListHandler(TaskBaseHandler):
    """
    :description: 任务列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 任务列表
        :param act_id:活动id
        :param task_types:任务类型字符串,分隔
        :return: 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        act_id = int(self.get_param("act_id", 0))
        task_types = self.get_param("task_types")

        task_info_model = TaskInfoModel(context=self)
        task_count_model = TaskCountModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        invite_log_model = InviteLogModel(context=self)
        act_prize_model = ActPrizeModel(context=self)
        prize_roster_model = PrizeRosterModel(context=self)

        task_list = []
        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        if not act_dict:
            return self.reponse_json_error("NoAct", "对不起，活动不存在")
        if not user_info:
            return self.reponse_json_error("NoUser", "对不起，用户不存在")
        task_info_list = task_info_model.get_list("act_id=%s and is_release=1", order_by="sort_index asc", params=[act_id])
        if len(task_info_list) <= 0:
            return self.reponse_json_success(task_list)
        now_day = SevenHelper.get_now_day_int()
        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("NoApp", "对不起，App不存在")

        for task_info in task_info_list:
            if task_types:
                if "," + str(task_info.task_type) + "," not in "," + task_types + ",":
                    continue
            task_config = self.json_loads(task_info.task_config)
            reward_value = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
            last_content = self.get_currency_type_name(self.get_task_currency_type(act_dict['task_currency_type'], task_info.task_type))
            if task_info.task_type == 1:  #新人有礼
                is_get = 0
                task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_info.task_type])
                if task_count:
                    is_get = 1
                result = {}
                result["title"] = "新人有礼"
                result["status"] = is_get
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["reward"] = reward_value
                result["type"] = "free"
                task_list.append(result)
            elif task_info.task_type == 2:  #每日签到
                is_sign = 0
                task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_info.task_type])
                if task_count and task_count.last_day == now_day:
                    is_sign = 1
                result = {}
                result["title"] = "每日签到"
                result["status"] = is_sign
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["reward"] = reward_value
                result["type"] = "sign"
                result["text"] = ["签到", "已签到"]
                task_list.append(result)
            elif task_info.task_type == 3:  #邀请
                user_limit = int(task_config["user_limit"]) if task_config.__contains__("user_limit") else 0
                today_invite = invite_log_model.get_dict_list("act_id=%s and open_id=%s and create_day=%s", params=[act_id, open_id, now_day])
                result = {}
                result["title"] = "成功邀请1名新用户"
                result["status"] = 1 if len(today_invite) >= user_limit else 0
                result["user_limit"] = user_limit
                result["invite_user_list"] = today_invite
                result["completed_quantity"] = len(today_invite)
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["reward"] = reward_value
                result["type"] = "invite"
                result["text"] = ["去邀请", "已完成"]
                task_list.append(result)
            elif task_info.task_type == 4:  #关注店铺
                result = {}
                result["title"] = "关注店铺"
                result["status"] = user_info.is_favor
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["store_name"] = app_info.store_name
                result["reward"] = reward_value
                result["type"] = "favor"
                result["text"] = ["去关注", "已关注"]
                task_list.append(result)
            elif task_info.task_type == 5:  #加入会员
                finish_status = 0  #2入会已领取0未入会1入会未领取
                join_member_url = ""
                if user_info.is_member != 1:
                    access_token = ""
                    if app_info:
                        access_token = app_info.access_token
                    is_member = self.check_is_member(access_token)
                    if is_member == True:
                        finish_status = 1
                    else:
                        finish_status = 0
                        join_member_url = self.get_join_member_url(access_token)
                else:
                    finish_status = 2
                result = {}
                result["title"] = "加入会员"
                result["join_member_url"] = join_member_url
                result["status"] = finish_status
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["reward"] = reward_value
                result["type"] = "member"
                result["text"] = ["立即入会", "立即领取", "已领取"]
                task_list.append(result)
            elif task_info.task_type == 6:  #下单
                result = {}
                effective_date_start = task_config["effective_date_start"] if task_config.__contains__("effective_date_start") else ""
                effective_date_end = task_config["effective_date_end"] if task_config.__contains__("effective_date_end") else ""
                result["date"] = [effective_date_start, effective_date_end]
                result["title"] = "下单任意1个商品" if reward_value > 0 else f"购买单品享多倍{last_content}"
                # result["title"] = "下单任意1个商品"
                result["goods_list"] = task_config["goods_list"] if task_config.__contains__("goods_list") else []
                result["num_limit"] = int(task_config["num_limit"]) if task_config.__contains__("num_limit") else 0
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["reward"] = reward_value
                result["type"] = "buy"
                result["text"] = ["去购买", "已购买"]
                task_list.append(result)
            elif task_info.task_type == 7:  #收藏
                collect_log_model = CollectLogModel(context=self)
                user_goods_list = collect_log_model.get_list("act_id=%s and open_id=%s", params=[act_id, open_id])
                completed_quantity = collect_log_model.get_total("act_id=%s and open_id=%s and create_day=%s", params=[act_id, open_id, now_day])
                result = {}
                result["title"] = "收藏任意1个商品"
                result["goods_list"] = task_config["goods_list"] if task_config.__contains__("goods_list") else []
                result["user_goods_list"] = [str(i.goods_id) for i in user_goods_list] if len(user_goods_list) > 0 else []
                result["num_limit"] = int(task_config["num_limit"]) if task_config.__contains__("num_limit") else 0
                result["completed_quantity"] = completed_quantity
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["reward"] = reward_value
                result["type"] = "collect"
                result["text"] = ["去收藏", "已收藏"]
                task_list.append(result)
            elif task_info.task_type == 8:  #浏览
                browse_log_model = BrowseLogModel(context=self)
                user_goods_list = browse_log_model.get_list("act_id=%s and open_id=%s", params=[act_id, open_id])
                completed_quantity = browse_log_model.get_total("act_id=%s and open_id=%s and create_day=%s", params=[act_id, open_id, now_day])
                result = {}
                result["title"] = "浏览任意1个商品"
                result["goods_list"] = task_config["goods_list"] if len(task_config["goods_list"]) > 0 else []
                result["user_goods_list"] = [str(i.goods_id) for i in user_goods_list] if len(user_goods_list) > 0 else []
                result["num_limit"] = int(task_config["num_limit"]) if task_config.__contains__("num_limit") else 0
                result["completed_quantity"] = completed_quantity
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["reward"] = reward_value
                result["type"] = "browse"
                result["text"] = ["去浏览", "已浏览"]
                task_list.append(result)
            elif task_info.task_type == 9:  #加入群聊
                finish_status = 0  #2入群已领取0未入群1入群未领取
                task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_info.task_type])
                if task_count:
                    finish_status = 2
                else:
                    access_token = ""
                    if app_info:
                        access_token = app_info.access_token
                    is_join_group = self.check_join_group(access_token)
                    if is_join_group == True:
                        finish_status = 1
                    else:
                        finish_status = 0

                chatting_group_url = ""
                if task_config.__contains__("join_type") and task_config["join_type"] == 1:
                    chatting_group_url = task_config["join_url"] if task_config.__contains__("join_url") else ""
                else:
                    chatting_group_url = "https://market.m.taobao.com/app/tb-chatting/join-group-landing/index/index.html?groupId=" + str(task_config["chatting_list"][0]["chatting_id"]) if task_config["chatting_list"][0] else ""

                result = {}
                result["title"] = "入群"
                result["status"] = finish_status
                result["chatting_group_url"] = chatting_group_url
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["reward"] = reward_value
                result["type"] = "join_chatting"
                result["text"] = ["立即加群", "立即领取", "已领取"]
                task_list.append(result)
            elif task_info.task_type == 12:  #每周签到
                signin = self.json_loads(user_info.signin) if user_info.signin else {"signin_date": "1900-01-01 00:00:00", "signin_value": 0}
                is_sign = 0
                task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_info.task_type])
                if task_count and task_count.last_day == now_day:
                    is_sign = 1
                reward_value = int(task_config[str(signin["signin_value"])]) if task_config.__contains__(str(signin["signin_value"])) else 0
                result = {}
                result["title"] = "每周签到"
                result["status"] = is_sign
                result["content"] = f"赠送+{reward_value}{last_content}"
                result["reward"] = reward_value
                result["type"] = "weekly_sign"
                result["count"] = signin["signin_value"] if TimeHelper.is_this_week(signin["signin_date"]) else 0
                result["text"] = ["签到", "已签到"]
                result["task_config"] = task_config
                task_list.append(result)
            elif task_info.task_type == 13:  #下单任意消费
                result = {}
                effective_date_start = task_config["effective_date_start"] if task_config["effective_date_start"] else ""
                effective_date_end = task_config["effective_date_end"] if task_config["effective_date_end"] else ""
                reward_value = reward_value if int(reward_value) != 0 else 1
                result["title"] = f"店内任意消费送{last_content}"
                result["date"] = [effective_date_start, effective_date_end]
                result["content"] = f"在店内消费成功后，积分奖励为实付1元={reward_value}{last_content}，取整数金额奖励{last_content}"
                result["reward"] = reward_value
                result["type"] = "arbitrarily_consumption"
                result["text"] = ["立即下单"]
                task_list.append(result)
            elif task_info.task_type == 14:  #累计消费
                result = {}
                effective_date_start = task_config["effective_date_start"] if task_config["effective_date_start"] else ""
                effective_date_end = task_config["effective_date_end"] if task_config["effective_date_end"] else ""
                reward_list = task_config["reward_list"] if task_config["reward_list"] else []
                count = 0
                for i in range(len(reward_list)):
                    if float(user_info.store_pay_price) >= float(reward_list[i]["money"]):
                        count += 1
                result["title"] = f"累计消费送{last_content}"
                result["date"] = [effective_date_start, effective_date_end]
                result["content"] = ["累计", r"满{}元"]
                result["unit"] = r"+{}" + last_content
                result["reward_list"] = reward_list
                result["type"] = "totle_consumption"
                result["count"] = count
                task_list.append(result)
            elif task_info.task_type == 15:  #单笔订单消费
                result = {}
                effective_date_start = task_config["effective_date_start"] if task_config["effective_date_start"] else ""
                effective_date_end = task_config["effective_date_end"] if task_config["effective_date_end"] else ""
                reward_list = task_config["reward_list"] if task_config["reward_list"] else []
                result["title"] = f"单笔消费送{last_content}"
                result["date"] = [effective_date_start, effective_date_end]
                result["content"] = r"单笔订单消费满{}元"
                result["reward_list"] = reward_list
                result["unit"] = r"+{}" + f"{last_content}奖励"
                result["type"] = "one_consumption"
                result["text"] = ["立即下单"]
                task_list.append(result)
            elif task_info.task_type == 16:  #店长好礼
                act_prize_list = act_prize_model.get_dict_list("act_id=%s and is_release=1 and ascription_type=1", "", "sort_index desc", "", "id,prize_name,surplus,lottery_sum", [act_id])
                if act_prize_list:
                    lottery_sum = int(user_info.lottery_sum) if user_info.lottery_sum else 0
                    for act_prize in act_prize_list:
                        prize_roster_have = prize_roster_model.get_total("open_id=%s and act_id=%s and prize_id=%s", params=[open_id, act_id, act_prize['id']])
                        if prize_roster_have > 0:
                            act_prize["code"] = 2
                            act_prize["text"] = "已领取"
                        elif act_prize["surplus"] <= 0:
                            act_prize["code"] = 3
                            act_prize["text"] = "已领完"
                        elif act_prize["lottery_sum"] > lottery_sum:
                            act_prize["code"] = 1
                            act_prize["text"] = f"还差{act_prize['lottery_sum']-lottery_sum}次可领取"
                        elif act_prize["lottery_sum"] <= lottery_sum:
                            act_prize["code"] = 0
                            act_prize["text"] = "立即领取"
                        result = {}
                        result["title"] = f"店长好礼"
                        result["content"] = r"领取条件：累计参与{}次转盘抽奖"
                        result["act_prize_list"] = act_prize_list
                        result["unit"] = "剩余{}件"
                        result["type"] = "shopowner_gift"
                        result["lottery_sum"] = lottery_sum
                        task_list.append(result)
            elif task_info.task_type == 17:  #抽奖送积分
                result = {}
                result["title"] = f"抽盒获得"
                result["content"] = f"每消耗一次抽盒次数+{reward_value}{last_content}"
                result["text"] = ["去抽盒"]
                result["type"] = "lottery_points"
                task_list.append(result)

        self.reponse_json_success(task_list)


class NewCourtesyHandler(TaskBaseHandler):
    """
    :description: 新人有礼任务
    """
    @filter_check_params("act_id,login_token")
    def get_async(self):
        """
        :description: 新人有礼任务
        :param act_id:活动id
        :param login_token:用户访问令牌
        :return: 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))

        task_info_model = TaskInfoModel(context=self)
        task_count_model = TaskCountModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 1  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        if user_info.is_new == 0:
            return self.reponse_json_error("Error", "对不起，新用户才能领取")
        now_day = SevenHelper.get_now_day_int()

        task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_type])
        if task_count:
            return self.reponse_json_error("Error", "对不起，已经领取过")
        task_count = TaskCount()
        task_count.app_id = app_id
        task_count.act_id = act_id
        task_count.open_id = open_id
        task_count.task_type = task_type
        task_count.count_value = 1
        task_count.last_day = now_day
        task_count.last_date = self.get_now_datetime()

        send_num = 0
        task_config = self.json_loads(task_info.task_config)
        if task_config:
            send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
        if send_num > 0:
            currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
            last_content = self.get_currency_type_name(currency_type)
            log_title = f"新人有礼+{send_num}{last_content}"
            if currency_type == 1:
                user_info.lottery_value = user_info.lottery_value + send_num
                update_sql = f"lottery_value=lottery_value+{send_num}"
                send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 201, currency_type)
            elif currency_type == 2:
                user_info.surplus_integral = user_info.surplus_integral + send_num
                update_sql = f"surplus_integral=surplus_integral+{send_num}"
                send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 201, currency_type)
            if send_result == False:
                return self.reponse_json_error("Error", "对不起，请稍后再试")

            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'FreeUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'FreeCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'FreeRewardCount', send_num, act_dict['act_type'])

        if task_count.id > 0:
            task_count_model.update_entity(task_count)
        else:
            task_count_model.add_entity(task_count)

        return self.reponse_json_success(send_num)


class EverySignHandler(TaskBaseHandler):
    """
    :description: 每日签到任务
    """
    @filter_check_params("act_id,login_token")
    def get_async(self):
        """
        :description: 每日签到任务
        :param act_id:活动id
        :param login_token:用户访问令牌
        :return: 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))

        task_info_model = TaskInfoModel(context=self)
        task_count_model = TaskCountModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 2  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        now_day = SevenHelper.get_now_day_int()

        task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_type])
        if task_count:
            if task_count.last_day == now_day:
                return self.reponse_json_error("Error", "今日已签到")
            task_count.last_day = now_day
            task_count.last_date = self.get_now_datetime()
        else:
            task_count = TaskCount()
            task_count.app_id = app_id
            task_count.act_id = act_id
            task_count.open_id = open_id
            task_count.task_type = task_type
            task_count.count_value = 1
            task_count.last_day = now_day
            task_count.last_date = self.get_now_datetime()

        send_num = 0
        task_config = self.json_loads(task_info.task_config)
        if task_config:
            send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
        if send_num > 0:
            currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
            last_content = self.get_currency_type_name(currency_type)
            log_title = f"签到+{send_num}{last_content}"
            # user_info.lottery_value = user_info.lottery_value + send_num
            # update_sql = f"lottery_value=lottery_value+{send_num}"
            #判断活动的抽奖货币类型来选择更新字段
            if currency_type == 1:
                user_info.lottery_value = user_info.lottery_value + send_num
                update_sql = f"lottery_value=lottery_value+{send_num}"
            elif currency_type == 2:
                user_info.surplus_integral = user_info.surplus_integral + send_num
                update_sql = f"surplus_integral=surplus_integral+{send_num}"
            send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 202, currency_type)
            if send_result == False:
                return self.reponse_json_error("Error", "对不起，请稍后再试")

            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'SignUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'SignCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'SignRewardCount', send_num, act_dict['act_type'])

        if task_count.id > 0:
            task_count_model.update_entity(task_count)
        else:
            task_count_model.add_entity(task_count)

        return self.reponse_json_success(send_num)


class ShareHandler(TaskBaseHandler):
    """
    :description: 用户分享
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 用户分享
        :param act_id:活动id
        :return 
        :last_editors: HuangJingCan
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        act_id = int(self.get_param("act_id", 0))

        act_dict = ActInfoModel(context=self).get_dict("id=%s and is_release=1", params=act_id)

        if not act_dict:
            return self.reponse_json_error_params()

        behavior_model = BehaviorModel(context=self)
        behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'ShareUserCount', 1, act_dict['act_type'])
        behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'ShareCount', 1, act_dict['act_type'])

        return self.reponse_json_success()


class InviteHandler(TaskBaseHandler):
    """
    :description: 邀请任务（被邀请人进入调用）
    """
    @filter_check_params("act_id,invite_open_id")
    def get_async(self):
        """
        :description: 邀请任务（被邀请人进入调用）
        :param act_id:活动id
        :param invite_open_id:邀请人
        :param is_task:是否任务
        :return: 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        act_id = int(self.get_param("act_id", 0))
        invite_open_id = self.get_param("invite_open_id")
        is_task = int(self.get_param("is_task", 1))
        # self.logging_link_info(str(invite_open_id) + "【InviteHandler】"+str(open_id))

        task_info_model = TaskInfoModel(context=self)
        task_count_model = TaskCountModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 3  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, "", False)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        if open_id == invite_open_id:
            return self.reponse_json_error("Error", "无效邀请")

        now_day = SevenHelper.get_now_day_int()
        invite_log_model = InviteLogModel(context=self)
        behavior_model = BehaviorModel(context=self)
        behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'ActiveUserCount', 1, act_dict['act_type'])
        behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'ActiveCount', 1, act_dict['act_type'])
        if is_task == 1:
            if user_info.is_new == 0:
                return self.reponse_json_error("Error", "此用户不是新用户")
            invite_count = invite_log_model.get_total("act_id=%s and invite_open_id=%s", params=[act_id, open_id])
            if invite_count > 0:
                return self.reponse_json_error("Error", "此用户已经被邀请过")
            task_config = self.json_loads(task_info.task_config)
            if not task_config:
                return self.reponse_json_error("Error", "未开启邀请任务")
            user_limit = int(task_config["user_limit"]) if task_config.__contains__("user_limit") else 0
            today_invite_count = invite_log_model.get_total("act_id=%s and open_id=%s and create_day=%s", params=[act_id, invite_open_id, now_day])
            if today_invite_count >= user_limit:
                return self.reponse_json_error("Error", "达到每日邀请好友上限")

            invite_log = InviteLog()
            invite_log.app_id = app_id
            invite_log.act_id = act_id
            invite_log.open_id = invite_open_id
            invite_log.invite_user_nick = user_info.user_nick
            invite_log.invite_open_id = open_id
            invite_log.invite_avatar = user_info.avatar
            invite_log.is_handle = 0
            invite_log.create_date = self.get_now_datetime()
            invite_log.create_day = now_day
            result = invite_log_model.add_entity(invite_log)
            if result <= 0:
                return self.reponse_json_error("Error", "邀请失败")

        return self.reponse_json_success()


class InviteRewardHandler(TaskBaseHandler):
    """
    :description: 邀请奖励（邀请人进入调用）
    """
    @filter_check_params("act_id,login_token")
    def get_async(self):
        """
        :description: 邀请奖励（邀请人进入调用）
        :param act_id:活动id
        :param login_token:login_token
        :return: 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))

        task_info_model = TaskInfoModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 3

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        now_day = SevenHelper.get_now_day_int()
        task_config = self.json_loads(task_info.task_config)
        if not task_config:
            return self.reponse_json_error("Error", "未开启邀请任务")
        invite_log_model = InviteLogModel(context=self)
        condition = "act_id=%s and open_id=%s and create_day=%s and is_handle=0"
        prams = [act_id, open_id, now_day]
        today_invite_list = invite_log_model.get_dict_list(condition, params=prams)
        today_invite_count = len(today_invite_list)
        reward_count = int(today_invite_count * int(task_config["reward_value"]))
        if reward_count <= 0:
            return self.reponse_json_error("Error", "未达到邀请奖励条件")
        if reward_count > 0:
            currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
            user_info.lottery_value = user_info.lottery_value + reward_count
            last_content = self.get_currency_type_name(currency_type)
            log_info = {}
            log_info["title"] = f"邀请{today_invite_count}人"
            log_info["invite_list"] = today_invite_list if today_invite_count > 0 else []
            log_title = f"邀请+{reward_count}{last_content}"
            invite_user_nick_list = [i['invite_user_nick'] for i in today_invite_list]
            log_desc = "被邀请用户：" + ",".join(invite_user_nick_list)
            #判断活动的抽奖货币类型来选择更新字段
            if currency_type == 1:
                user_info.lottery_value = user_info.lottery_value + reward_count
                update_sql = f"lottery_value=lottery_value+{reward_count}"
            elif currency_type == 2:
                user_info.surplus_integral = user_info.surplus_integral + reward_count
                update_sql = f"surplus_integral=surplus_integral+{reward_count}"
            send_result = self.send_lottery_value(log_title, user_info, update_sql, reward_count, act_dict, 2, 203, currency_type, log_info, log_desc)
            if send_result == False:
                return self.reponse_json_error("Error", "邀请成功,系统异常未给奖励")
            invite_log_model.update_table("is_handle=1", SevenHelper.get_condition_by_id_list("id", [i['id'] for i in today_invite_list]))

            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'InviteUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'InviteCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'InviteRewardCount', reward_count, act_dict['act_type'])

        return self.reponse_json_success(reward_count)


class FollowHandler(TaskBaseHandler):
    """
    :description: 关注任务
    """
    @filter_check_params("act_id,login_token")
    def get_async(self):
        """
        :description: 关注任务
        :param act_id:活动id
        :param login_token:用户访问令牌
        :return 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))

        task_info_model = TaskInfoModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 4  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token, False)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        if user_info.is_favor == 1:
            return self.reponse_json_error("Error", "已经关注过店铺了")
        if not task_info or task_info.is_release == 0:
            user_info_model.update_table("is_favor=1", "id=%s", params=user_info.id)
            return self.reponse_json_success()

        task_config = self.json_loads(task_info.task_config)
        send_num = 0
        if not task_config:
            return self.reponse_json_error("Error", "未开启加入店铺任务")
        send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
        if send_num > 0:
            user_info.is_favor = 1
            currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
            last_content = self.get_currency_type_name(currency_type)
            log_title = f"关注店铺+{send_num}{last_content}"
            #判断活动的抽奖货币类型来选择更新字段
            if currency_type == 1:
                user_info.lottery_value = user_info.lottery_value + send_num
                update_sql = f"lottery_value=lottery_value+{send_num},is_favor=1"
            elif currency_type == 2:
                user_info.surplus_integral = user_info.surplus_integral + send_num
                update_sql = f"surplus_integral=surplus_integral+{send_num},is_favor=1"
            send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 204, currency_type)
            if send_result == False:
                return self.reponse_json_error("Error", "关注店铺成功,系统异常未给奖励")

            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'FollowUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'FollowCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'FollowRewardCount', send_num, act_dict['act_type'])

        return self.reponse_json_success(send_num)


class JoinMemberRewardHandler(TaskBaseHandler):
    """
    :description: 加入会员任务
    """
    @filter_check_params("act_id,login_token")
    def get_async(self):
        """
        :description: 加入会员任务
        :param act_id:活动id
        :param login_token:用户访问令牌
        :return 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))

        task_info_model = TaskInfoModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 5  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token, False)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        if user_info.is_member == 1:
            return self.reponse_json_error("Error", "已经加入会员了")
        access_token = ""
        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if app_info:
            access_token = app_info.access_token
        is_member = self.check_is_member(access_token)
        if is_member == False:
            return self.reponse_json_error("Error", "对不起，您未加入会员")
        if not task_info or task_info.is_release == 0:
            user_info_model.update_table("is_member=1", "id=%s", params=user_info.id)
            return self.reponse_json_success()

        task_config = self.json_loads(task_info.task_config)
        if not task_config:
            return self.reponse_json_error("Error", "未开启加入会员任务")
        send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
        if send_num > 0:
            user_info.is_member = 1
            currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
            last_content = self.get_currency_type_name(currency_type)
            log_title = f"加入会员+{send_num}{last_content}"
            #判断活动的抽奖货币类型来选择更新字段
            if currency_type == 1:
                user_info.lottery_value = user_info.lottery_value + send_num
                update_sql = f"lottery_value=lottery_value+{send_num},is_member=1"
            elif currency_type == 2:
                user_info.surplus_integral = user_info.surplus_integral + send_num
                update_sql = f"surplus_integral=surplus_integral+{send_num},is_member=1"
            send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 205, currency_type)
            if send_result == False:
                return self.reponse_json_error("Error", "加入会员成功,系统异常未给奖励")

            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'MemberUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'MemberCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'MemberRewardCount', send_num, act_dict['act_type'])

        return self.reponse_json_success(send_num)


class GetMemberUrlHandler(TaskBaseHandler):
    """
    :description: 获取入会地址
    """
    def get_async(self):
        """
        :description: 获取入会地址
        :return: str
        :last_editors: LaiKaiXiang
        """
        app_id = self.get_taobao_param().source_app_id

        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("NoApp", "对不起，App不存在")

        access_token = app_info.access_token
        join_member_url = self.get_join_member_url(access_token)

        return self.reponse_json_success(join_member_url)


class CollectGoodsHandler(TaskBaseHandler):
    """
    :description: 收藏商品任务
    """
    @filter_check_params("act_id,goods_id,login_token")
    def get_async(self):
        """
        :description: 收藏商品任务
        :param act_id:活动id
        :param login_token:用户访问令牌
        :return 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))
        goods_id = int(self.get_param("goods_id"))
        goods_name = self.get_param("goods_name")

        task_info_model = TaskInfoModel(context=self)
        task_count_model = TaskCountModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 7  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        task_config = self.json_loads(task_info.task_config)
        if not task_config:
            return self.reponse_json_error("Error", "未开启收藏商品任务")
        if task_config["goods_ids"] == "":
            return self.reponse_json_error("Error", "没有配置收藏商品")
        task_config["goods_ids"] = "," + task_config["goods_ids"] + ","
        if "," + str(goods_id) + "," not in task_config["goods_ids"]:
            return self.reponse_json_error("Error", "当前商品不在收藏任务里")
        collect_log_model = CollectLogModel(context=self)
        collect_count = collect_log_model.get_total("act_id=%s and open_id=%s and goods_id=%s", params=[act_id, open_id, goods_id])
        if collect_count > 0:
            return self.reponse_json_error("Error", "当前商品已经收藏")
        now_day = SevenHelper.get_now_day_int()

        task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_type])
        if task_count:
            if task_count.last_day == now_day:
                task_count.count_value += 1
            else:
                task_count.count_value = 1
                task_count.last_day = now_day
                task_count.last_date = self.get_now_datetime()
        else:
            task_count = TaskCount()
            task_count.app_id = app_id
            task_count.act_id = act_id
            task_count.open_id = open_id
            task_count.task_type = task_type
            task_count.count_value = 1
            task_count.last_day = now_day
            task_count.last_date = self.get_now_datetime()

        num_limit = int(task_config["num_limit"]) if task_config.__contains__("num_limit") else 0
        if task_count.count_value > num_limit:
            return self.reponse_json_error("Error", "达到每日奖励上限")

        send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
        if send_num > 0:
            currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
            last_content = self.get_currency_type_name(currency_type)
            log_info = {}
            log_info["title"] = f"商品ID：{str(goods_id)}"
            log_info["goods_id"] = goods_id
            log_info["goods_name"] = goods_name
            log_title = f"收藏商品+{send_num}{last_content}"
            #判断活动的抽奖货币类型来选择更新字段
            if currency_type == 1:
                user_info.lottery_value = user_info.lottery_value + send_num
                update_sql = f"lottery_value=lottery_value+{send_num}"
            elif currency_type == 2:
                user_info.surplus_integral = user_info.surplus_integral + send_num
                update_sql = f"surplus_integral=surplus_integral+{send_num}"
            log_desc = log_info["title"]
            send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 207, currency_type, log_info, log_desc)
            if send_result == False:
                return self.reponse_json_error("Error", "对不起，请稍后再试")

            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'CollectUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'CollectCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'CollectRewardCount', send_num, act_dict['act_type'])

        if task_count.id > 0:
            task_count_model.update_entity(task_count)
        else:
            task_count_model.add_entity(task_count)

        collect_log = CollectLog()
        collect_log.app_id = app_id
        collect_log.act_id = act_id
        collect_log.open_id = open_id
        collect_log.goods_id = goods_id
        collect_log.is_handle = 1
        collect_log.create_date = self.get_now_datetime()
        collect_log.create_day = now_day
        collect_log_model.add_entity(collect_log)

        return self.reponse_json_success(send_num)


class BrowseGoodsHandler(TaskBaseHandler):
    """
    :description: 浏览商品任务
    """
    @filter_check_params("act_id,goods_id,login_token")
    def get_async(self):
        """
        :description: 浏览商品任务
        :param act_id:活动id
        :param login_token:用户访问令牌
        :return 
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))
        goods_id = int(self.get_param("goods_id"))
        goods_name = self.get_param("goods_name")

        task_info_model = TaskInfoModel(context=self)
        task_count_model = TaskCountModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 8  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        task_config = self.json_loads(task_info.task_config)
        if not task_config:
            return self.reponse_json_error("Error", "未开启浏览商品任务")
        if task_config["goods_ids"] == "":
            return self.reponse_json_error("Error", "没有配置浏览商品")
        task_config["goods_ids"] = "," + task_config["goods_ids"] + ","
        if "," + str(goods_id) + "," not in task_config["goods_ids"]:
            return self.reponse_json_error("Error", "当前商品不在浏览任务里")

        browse_log_model = BrowseLogModel(context=self)
        browse_count = browse_log_model.get_total("act_id=%s and open_id=%s and goods_id=%s", params=[act_id, open_id, goods_id])
        if browse_count > 0:
            return self.reponse_json_error("Error", "当前商品已经浏览过")
        now_day = SevenHelper.get_now_day_int()
        task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_type])
        if task_count:
            if task_count.last_day == now_day:
                task_count.count_value += 1
            else:
                task_count.count_value = 1
                task_count.last_day = now_day
                task_count.last_date = self.get_now_datetime()
        else:
            task_count = TaskCount()
            task_count.app_id = app_id
            task_count.act_id = act_id
            task_count.open_id = open_id
            task_count.task_type = task_type
            task_count.count_value = 1
            task_count.last_day = now_day
            task_count.last_date = self.get_now_datetime()

        num_limit = int(task_config["num_limit"]) if task_config.__contains__("num_limit") else 0
        if task_count.count_value > num_limit:
            return self.reponse_json_error("Error", "达到每日奖励上限")

        send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
        if send_num > 0:
            currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
            last_content = self.get_currency_type_name(currency_type)
            log_info = {}
            log_info["title"] = f"商品ID：{str(goods_id)}"
            log_info["goods_id"] = goods_id
            log_info["goods_name"] = goods_name
            log_title = f"浏览商品+{send_num}{last_content}"
            #判断活动的抽奖货币类型来选择更新字段
            if currency_type == 1:
                user_info.lottery_value = user_info.lottery_value + send_num
                update_sql = f"lottery_value=lottery_value+{send_num}"
            elif currency_type == 2:
                user_info.surplus_integral = user_info.surplus_integral + send_num
                update_sql = f"surplus_integral=surplus_integral+{send_num}"
            log_desc = log_info["title"]
            send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 208, currency_type, log_info, log_desc)
            if send_result == False:
                return self.reponse_json_error("Error", "对不起，请稍后再试")

            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'BrowseUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'BrowseCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'BrowseRewardCount', send_num, act_dict['act_type'])

        if task_count.id > 0:
            task_count_model.update_entity(task_count)
        else:
            task_count_model.add_entity(task_count)

        browse_log = BrowseLog()
        browse_log.app_id = app_id
        browse_log.act_id = act_id
        browse_log.open_id = open_id
        browse_log.goods_id = goods_id
        browse_log.is_handle = 1
        browse_log.create_date = self.get_now_datetime()
        browse_log.create_day = now_day
        browse_log_model.add_entity(browse_log)

        return self.reponse_json_success(send_num)


class BuyGoodsHandler(TaskBaseHandler):
    """
    :description: 指定商品下单任务
    """
    @filter_check_params("act_id,login_token")
    def get_async(self):
        """
        :description: 指定商品下单任务
        :param act_id:活动id
        :param login_token:用户访问令牌
        :return:
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))

        act_info_model = ActInfoModel(context=self)
        task_count_model = TaskCountModel(context=self)
        task_info_model = TaskInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 6  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        task_config = self.json_loads(task_info.task_config)
        if not task_config:
            return self.reponse_json_error("Error", "未开启下单商品任务")
        if task_config.__contains__("goods_ids") == False or task_config["goods_ids"] == "":
            return self.reponse_json_error("Error", "没有配置下单商品")

        now_day = SevenHelper.get_now_day_int()
        task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_type])
        # if task_count:
        #     if task_count.last_day == now_day:
        #         task_count.count_value += 1
        #     else:
        #         task_count.count_value = 1
        #         task_count.last_day = now_day
        #         task_count.last_date = self.get_now_datetime()
        # else:
        #     task_count = TaskCount()
        #     task_count.app_id = app_id
        #     task_count.act_id = act_id
        #     task_count.open_id = open_id
        #     task_count.task_type = task_type
        #     task_count.count_value = 1
        #     task_count.last_day = now_day
        #     task_count.last_date = self.get_now_datetime()

        num_limit = int(task_config["num_limit"]) if task_config.__contains__("num_limit") else 0
        # if task_count.count_value > num_limit:
        #     return self.reponse_json_error("Error", "达到每日奖励上限")

        access_token = ""
        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=self.get_taobao_param().source_app_id)
        if app_info:
            access_token = app_info.access_token
        # 获取订单
        order_data = []
        if task_config.__contains__("effective_date_start") == True and task_config.__contains__("effective_date_end") == True and task_config["effective_date_start"] != "" and task_config["effective_date_end"] != "":
            order_data = self.get_taobao_order(open_id, access_token, task_config.effective_date_start, task_config.effective_date_end)
        if act_dict['start_date'] != "":
            order_data = self.get_taobao_order(open_id, access_token, act_dict['start_date'])
        else:
            order_data = self.get_taobao_order(open_id, access_token)

        # self.logging_link_info(str(order_data) + "【订单列表】")

        pay_order_model = PayOrderModel(context=self)
        pay_order_list = pay_order_model.get_list("app_id=%s and open_id=%s and act_id=%s", params=[app_id, open_id, act_id])

        pay_order_id_list = []
        for item in pay_order_list:
            pay_order_id_list.append(item.order_no)

        buy_goods_id_list = []
        for item in task_config["goods_ids"].split(","):
            buy_goods_id_list.append(item)

        #所有订单(排除交易结束订单)
        all_sub_order_list = []
        #所有相关商品订单
        all_goods_order_list = []

        #过滤掉不奖励的数据和跟活动无关的订单
        if order_data:
            for item in order_data:
                for order in item["orders"]["order"]:
                    if str(order["num_iid"]) in buy_goods_id_list:
                        if order["status"] in self.rewards_status():
                            order["pay_time"] = item["pay_time"]
                            order["tid"] = item["tid"]
                            all_sub_order_list.append(order)
                        if "pay_time" in item:
                            order["tid"] = item["tid"]
                            order["pay_time"] = item["pay_time"]
                            all_goods_order_list.append(order)

        # self.logging_link_info(str(all_goods_order_list) + "【all_goods_order_list】")

        total_pay_num = 0  #总支付笔数
        total_reward_num = 0  #总奖励值
        total_pay_prize = 0  #总支付金额
        total_pay_order_num = 0  #总订单数
        user_info_dict = {}
        try:
            for order in all_sub_order_list:
                #判断是否已经加过奖励
                if order["oid"] not in pay_order_id_list:

                    if task_count:
                        if task_count.last_day == now_day:
                            task_count.count_value += 1
                        else:
                            task_count.count_value = 1
                            task_count.last_day = now_day
                            task_count.last_date = self.get_now_datetime()
                    else:
                        task_count = TaskCount()
                        task_count.app_id = app_id
                        task_count.act_id = act_id
                        task_count.open_id = open_id
                        task_count.task_type = task_type
                        task_count.count_value = 1
                        task_count.last_day = now_day
                        task_count.last_date = self.get_now_datetime()

                    pay_order = PayOrder()
                    pay_order.app_id = app_id
                    pay_order.act_id = act_id
                    pay_order.open_id = open_id
                    pay_order.owner_open_id = act_dict['owner_open_id']
                    pay_order.user_nick = user_info.user_nick
                    pay_order.main_order_no = order['tid']
                    pay_order.order_no = order['oid']
                    pay_order.goods_code = order['num_iid']
                    pay_order.goods_name = order['title']
                    if "sku_id" in order.keys():
                        pay_order.sku_id = order['sku_id']
                    pay_order.buy_num = order['num']
                    pay_order.pay_price = order['payment']
                    pay_order.order_status = order['status']
                    pay_order.create_date = self.get_now_datetime()
                    pay_order.pay_date = order['pay_time']

                    send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0

                    #获得次数
                    prize_count = int(order["num"])
                    pay_price = decimal.Decimal(order["payment"])
                    user_info.lottery_value += send_num
                    user_info.pay_num += prize_count
                    user_info.pay_price = str(decimal.Decimal(user_info.pay_price) + pay_price)
                    currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
                    last_content = self.get_currency_type_name(act_dict['currency_type'])
                    log_info = {}
                    log_info["title"] = f"商品ID：{str(order['num_iid'])}"
                    log_info["goods_id"] = order['num_iid']
                    log_info["goods_name"] = order['title']
                    log_info["order"] = order

                    if send_num <= 0:
                        if task_config.__contains__("goods_list"):
                            for goods in task_config["goods_list"]:
                                if str(goods["num_iid"]) == str(order['num_iid']):
                                    send_num = int(goods["reward_value"]) if goods.__contains__("reward_value") else 0
                    log_title = f"购买商品+{send_num}{last_content}"
                    update_sql = f"pay_num=pay_num+{prize_count},pay_price=pay_price+{pay_price},lottery_value=lottery_value+{send_num}"
                    log_desc = f"淘宝订单号：{pay_order.main_order_no}；" + log_info["title"]
                    send_result = False
                    if task_count.count_value > num_limit:
                        send_result = True
                    else:
                        # return self.reponse_json_error("Error", "达到每日奖励上限")
                        send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 206, currency_type, log_info, log_desc)
                    if send_result == False:
                        continue
                    send_num = 0 if task_count.count_value > num_limit else send_num
                    total_reward_num += send_num
                    total_pay_num += 1
                    total_pay_prize = str(decimal.Decimal(total_pay_prize) + decimal.Decimal(order["payment"]))
                    total_pay_order_num += int(order["num"])
                    user_info_dict = user_info.__dict__
                    if "sku_id" in order.keys():
                        pay_order.sku_name = self.get_sku_name(int(order['num_iid']), int(order['sku_id']), access_token)
                    pay_order_id = pay_order_model.add_entity(pay_order)
                    #添加记录
                    coin_order_model = CoinOrderModel(context=self)
                    coin_order = CoinOrder()
                    coin_order.open_id = open_id
                    coin_order.app_id = app_id
                    coin_order.act_id = act_id
                    coin_order.reward_type = 0
                    coin_order.goods_name = pay_order.goods_name
                    coin_order.goods_price = pay_order.pay_price
                    coin_order.sku = pay_order.sku_id
                    coin_order.nick_name = pay_order.user_nick
                    coin_order.main_pay_order_no = pay_order.main_order_no
                    coin_order.pay_order_no = pay_order.order_no
                    coin_order.pay_order_id = pay_order_id
                    coin_order.buy_count = prize_count
                    coin_order.surplus_count = 0 if task_count.count_value > num_limit else prize_count
                    coin_order.pay_date = pay_order.pay_date
                    coin_order.create_date = self.get_now_datetime()
                    coin_order.modify_date = self.get_now_datetime()
                    coin_order_model.add_entity(coin_order)

                    if task_count.id > 0:
                        task_count_model.update_entity(task_count)
                    else:
                        task_count_model.add_entity(task_count)

        except Exception as ex:
            # self.logging_link_info(str(all_sub_order_list) + "【任务订单列表】" + str(ex))
            return self.reponse_json_error('Error', '任务获取订单失败', str(ex))

        is_black = self.check_black(user_info, act_dict, all_goods_order_list)
        if total_reward_num > 0:
            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'BuyUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'BuyCount', total_pay_num, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'BuyRewardCount', total_reward_num, act_dict['act_type'])

            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'PayMoneyCount', decimal.Decimal(total_pay_prize), act_dict['act_type'])

        result = {}
        result["is_black"] = is_black
        result["reward_num"] = total_reward_num

        return self.reponse_json_success(result)


class JoinChattingRewardHandler(TaskBaseHandler):
    """
    :description: 加入群聊奖励接口
    """
    @filter_check_params("act_id,login_token")
    def get_async(self):
        """
        :description: 加入群聊奖励接口
        :param act_id:活动id
        :param login_token:login_token
        :return:
        :last_editors: HuangJianYi
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))

        task_info_model = TaskInfoModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_count_model = TaskCountModel(context=self)
        task_type = 9

        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("Error", "对不起,应用不存在")
        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        now_day = SevenHelper.get_now_day_int()

        task_config = self.json_loads(task_info.task_config)
        send_num = 0
        if not task_config:
            return self.reponse_json_error("Error", "未开启入群任务")
        send_num = int(task_config["reward_value"]) if task_config.__contains__("reward_value") else 0
        reward_task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_info.task_type])
        if reward_task_count:
            return self.reponse_json_error("Error", "对不起，请勿重复领取")
        is_join_group = self.check_join_group(app_info.access_token)
        if is_join_group == False:
            return self.reponse_json_error("Error", "对不起，您还未加入群聊")
        reward_count = int(task_config["reward_value"])
        if reward_count <= 0:
            return self.reponse_json_error("Error", "未达到入群奖励条件")

        if send_num > 0:
            user_info.surplus_integral = user_info.surplus_integral + send_num
            currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
            last_content = self.get_currency_type_name(currency_type)
            chatting_id = str(task_config["chatting_list"][0]["chatting_id"]) if task_config["chatting_list"][0] else ""
            chatting_name = str(task_config["chatting_list"][0]["chatting_name"]) if task_config["chatting_list"][0] else ""
            log_info = {}
            log_info["title"] = f"群聊ID：{chatting_id}" if chatting_id else ""
            log_info["chatting_id"] = chatting_id
            log_info["chatting_name"] = chatting_name
            log_title = f"入群+{send_num}{last_content}"
            #判断活动的抽奖货币类型来选择更新字段
            if currency_type == 1:
                user_info.lottery_value = user_info.lottery_value + send_num
                update_sql = f"lottery_value=lottery_value+{send_num}"
            elif currency_type == 2:
                user_info.surplus_integral = user_info.surplus_integral + send_num
                update_sql = f"surplus_integral=surplus_integral+{send_num}"
            log_desc = log_info["title"]
            send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 209, currency_type, log_info, log_desc)
            if send_result == False:
                return self.reponse_json_error("Error", "入群成功,系统异常未给奖励")

            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'JoinGroupUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'JoinGroupCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'JoinGroupRewardCount', send_num, act_dict['act_type'])

            task_count = TaskCount()
            task_count.app_id = app_id
            task_count.act_id = act_id
            task_count.open_id = open_id
            task_count.task_type = task_type
            task_count.task_sub_type = ""
            task_count.count_value = 1
            task_count.last_day = now_day
            task_count.last_date = self.get_now_datetime()
            task_count_model.add_entity(task_count)

        return self.reponse_json_success(send_num)


class WeeklySignHandler(TaskBaseHandler):
    """
    :description: 每周签到任务
    """
    @filter_check_params("act_id,login_token")
    def get_async(self):
        """
        :description: 每周签到任务
        :param act_id:活动id
        :param login_token:用户访问令牌
        :return: 
        :last_editors: ChenCheng
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))

        task_info_model = TaskInfoModel(context=self)
        task_count_model = TaskCountModel(context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        task_type = 12  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("app_id=%s and act_id=%s and open_id=%s", params=[app_id, act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])
        now_day = SevenHelper.get_now_day_int()

        task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_type])
        if task_count:
            if task_count.last_day == now_day:
                return self.reponse_json_error("Error", "今日已签到")
            task_count.count_value += 1
            task_count.last_day = now_day
            task_count.last_date = self.get_now_datetime()
        else:
            task_count = TaskCount()
            task_count.app_id = app_id
            task_count.act_id = act_id
            task_count.open_id = open_id
            task_count.task_type = task_type
            task_count.count_value = 1
            task_count.last_day = now_day
            task_count.last_date = self.get_now_datetime()

        send_num = 0
        task_config = self.json_loads(task_info.task_config)
        signin = self.json_loads(user_info.signin) if user_info.signin else {"signin_date": "1900-01-01 00:00:00", "signin_value": 0}
        # updata_signin = UpdataSignModel(context=self)
        updata_signin = {}
        updata_signin['signin_value'] = signin["signin_value"]
        updata_signin['signin_date'] = TimeHelper.get_now_format_time()
        # updata_signin["signin_date"] = TimeHelper.get_now_format_time()
        if task_config:
            if TimeHelper.is_this_week(signin["signin_date"]):
                updata_signin['signin_value'] = signin["signin_value"] + 1
            else:
                updata_signin['signin_value'] = 1
            send_num = int(task_config[str(updata_signin['signin_value'])]) if task_config.__contains__(str(updata_signin['signin_value'])) else 0
        if send_num > 0:
            user_info.surplus_integral = user_info.surplus_integral + send_num
            currency_type = self.get_task_currency_type(act_dict['task_currency_type'], task_type)
            last_content = self.get_currency_type_name(currency_type)
            log_title = f"周累计签到{updata_signin['signin_value']}天"
            log_desc = log_title
            update_sql = f"surplus_integral=surplus_integral+{send_num},signin='{self.json_dumps(updata_signin)}'"
            # print(update_sql)
            send_result = self.send_lottery_value(log_title, user_info, update_sql, send_num, act_dict, 2, 2012, currency_type, log_desc)
            if send_result == False:
                return self.reponse_json_error("Error", "对不起，请稍后再试")

            behavior_model = BehaviorModel(context=self)
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'SignUserCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'SignCount', 1, act_dict['act_type'])
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'SignRewardCount', send_num, act_dict['act_type'])

        if task_count.id > 0:
            task_count_model.update_entity(task_count)
        else:
            task_count_model.add_entity(task_count)

        return self.reponse_json_success(send_num)


class ShopownerGiftHandler(TaskBaseHandler):
    """
    :description: 店长好礼任务（注意：添加或者删除奖品的时候需要新增或者删除orm_key）
    """
    @filter_check_params("act_id,login_token")
    def get_async(self):
        """
        :description: 店长好礼任务（注意：添加或者删除奖品的时候需要新增或者删除orm_key）
        :param act_id:活动id
        :param login_token:用户访问令牌
        :return: 
        :last_editors: ChenCheng 
        """
        open_id = self.get_taobao_param().open_id
        app_id = self.get_taobao_param().source_app_id
        login_token = self.get_param("login_token")
        act_id = int(self.get_param("act_id", 0))
        prize_id = int(self.get_param("prize_id", 0))
        log_info = {}

        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
        task_info_model = TaskInfoModel(context=self)
        task_count_model = TaskCountModel(db_transaction=db_transaction, context=self)
        act_info_model = ActInfoModel(context=self)
        user_info_model = UserInfoModel(context=self)
        act_prize_model = ActPrizeModel(db_transaction=db_transaction, context=self)
        prize_roster_model = PrizeRosterModel(db_transaction=db_transaction, context=self)
        task_type = 16  #任务类型

        act_dict = act_info_model.get_dict("id=%s and is_release=1", params=act_id)
        user_info = user_info_model.get_entity("app_id=%s and act_id=%s and open_id=%s", params=[app_id, act_id, open_id])
        task_info = task_info_model.get_entity("act_id=%s and task_type=%s", params=[act_id, task_type])
        invoke_result = self.check_common(act_dict, user_info, task_info, act_id, open_id, login_token)
        if invoke_result["code"] != "0":
            return self.reponse_json_error(invoke_result["code"], invoke_result["message"])

        prize_roster_have = prize_roster_model.get_entity("open_id=%s and act_id=%s and prize_id=%s", params=[open_id, act_id, prize_id])
        if prize_roster_have:
            return self.reponse_json_error("Error", "对不起，已经领取过")

        act_prize = act_prize_model.get_entity("act_id=%s and is_release=1 and id=%s", params=[act_id, prize_id])
        if act_prize:
            if act_prize.lottery_sum > user_info.lottery_sum:
                return self.reponse_json_error("Error", "对不起，未达到领取要求")
        else:
            return self.reponse_json_error("Error", "对不起，奖品不存在")

        #添加记录，同步奖品库存
        try:
            #任务完成记录
            now_day = SevenHelper.get_now_day_int()
            task_count = task_count_model.get_entity("act_id=%s and open_id=%s and task_type=%s", params=[act_id, open_id, task_type])
            if task_count:
                task_count.count_value += 1
                task_count.last_day = now_day
                task_count.last_date = self.get_now_datetime()
            else:
                task_count = TaskCount()
                task_count.app_id = app_id
                task_count.act_id = act_id
                task_count.open_id = open_id
                task_count.task_type = task_type
                task_count.count_value = 1
                task_count.last_day = now_day
                task_count.last_date = self.get_now_datetime()

            #录入中奖记录
            prize_roster = PrizeRoster()
            prize_roster.app_id = app_id
            prize_roster.act_id = act_id
            prize_roster.open_id = open_id
            prize_roster.prize_id = act_prize.id
            prize_roster.prize_name = act_prize.prize_name
            prize_roster.prize_price = act_prize.prize_price
            prize_roster.prize_pic = act_prize.prize_pic
            prize_roster.prize_detail = act_prize.prize_detail
            prize_roster.prize_type = act_prize.prize_type
            prize_roster.award_name = act_prize.tag_name if act_prize.tag_name else ""
            prize_roster.user_nick = user_info.user_nick
            prize_roster.goods_id = act_prize.goods_id
            prize_roster.is_sku = act_prize.is_sku
            prize_roster.goods_code = act_prize.goods_code
            prize_roster.goods_code_list = act_prize.goods_code_list
            prize_roster.sku_detail = act_prize.sku_detail
            prize_roster.avatar = user_info.avatar
            prize_roster.create_date = self.get_now_datetime()

            db_transaction.commit_transaction()

            #过滤并发情况，奖品剩余件数已不足
            result = act_prize_model.update_table("surplus=surplus-1,hand_out=hand_out+1", "id=%s and surplus>0", act_prize.id)
            if not result:
                return self.reponse_json_error("Error", "对不起，领取失败，请刷新")

            prize_roster_id = prize_roster_model.add_entity(prize_roster)
            prize_roster.id = prize_roster_id
            if task_count.id > 0:
                task_count_model.update_entity(task_count)
            else:
                task_count_model.add_entity(task_count)

            log_info["code"] = "Success"
            log_info["message"] = prize_roster.__dict__
        except Exception as ex:
            # self.logging_link_error(str(ex) + "【店长好礼任务】")
            db_transaction.rollback_transaction()
            log_info["code"] = "Exception"
            log_info["message"] = ex
            # print(log_info)
            return self.reponse_json_error("Error", "对不起，领取失败", ex)

        if log_info["code"] == "Success":
            behavior_model = BehaviorModel(context=self)
            # 完成次数：保底_累计抽xx次
            behavior_model.report_behavior_log(app_id, act_id, open_id, act_dict['owner_open_id'], 'ShopownerGiftCount_' + str(prize_id), 1, act_dict['act_type'])

        return self.reponse_json_success(prize_roster)


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-19 11:59:38
:LastEditTime: 2021-04-14 16:05:36
:LastEditors: HuangJingCan
:description: 
"""
__all__ = ["act", "address", "app", "exchange", "goods", "lottery", "machine", "power", "prize", "series", "task", "theme", "user"]




#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *


class LotteryValueLogModel(BaseModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(LotteryValueLogModel, self).__init__(LotteryValueLog, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类
    
class LotteryValueLog:

    def __init__(self):
        super(LotteryValueLog, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # app_id
        self.act_id = 0  # act_id
        self.open_id = ""  # open_id
        self.user_nick = ""  # 用户昵称
        self.log_title = ""  # 标题
        self.log_desc = ""  # 备注
        self.log_info = ""  # 信息
        self.currency_type = 0  # 抽奖货币类型（0无1次数2积分3价格档位）
        self.source_type = 0  # 来源类型：1-购买2-任务3-手动配置4抽奖
        self.change_type = 0  # 变动类型(来源类型+对用的子类型  如:101下单购买201新人有礼202每日签到301手动增加302手动减少401抽奖增加402抽奖减少)
        self.operate_type = 0  # 操作类型(0累计 1消耗)
        self.current_value = 0  # 改动的值
        self.history_value = 0  # 未变化前用户值
        self.main_pay_order_no = ""  # 淘宝主订单号
        self.operator = ""  # 操作人
        self.create_date = "1900-01-01 00:00:00"  # 创建时间

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'open_id', 'user_nick', 'log_title', 'log_desc', 'log_info', 'currency_type', 'source_type', 'change_type', 'operate_type', 'current_value', 'history_value', 'main_pay_order_no', 'operator', 'create_date']
        
    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "lottery_value_log_tb"
    


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2021-04-14 15:02:54
@LastEditTime: 2021-04-15 16:14:26
@LastEditors: HuangJianYi
:Description: 用户权限相关
"""
from seven_cloudapp.handlers.seven_base import *


class GetPowerMenuHandler(SevenBaseHandler):
    """
    :description: 获取权限菜单列表
    """
    def get_async(self):
        """
        :description: 获取权限菜单列表
        :return: dict
        :last_editors: HuangJianYi
        """
        app_id = self.get_taobao_param().source_app_id

        data = self.get_power_menu(app_id)

        return self.reponse_json_success(data)


# -*- coding: utf-8 -*-
"""
:Author: CaiYouBin
:Date: 2020-05-12 20:04:54
:LastEditTime: 2021-04-16 14:22:51
:LastEditors: HuangJingCan
:description: 基础接口
"""
from seven_framework.qr_code import *
from seven_cloudapp.handlers.seven_base import *

from seven_cloudapp.models.enum import *
from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.db_models.theme.theme_info_model import *
from seven_cloudapp.models.db_models.skin.skin_info_model import *
from seven_cloudapp.models.db_models.act.act_prize_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.act.act_type_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *
from seven_cloudapp.models.db_models.base.base_info_model import *
from seven_cloudapp.models.db_models.marketing.marketing_program_model import *


class MarketingProgramHandler(SevenBaseHandler):
    """
    :description: 营销方案
    """
    def get_async(self):
        """
        :description: 营销方案获取
        :param {type} 
        :return: 列表
        :last_editors: HuangJingCan
        """
        marketing_program_list = MarketingProgramModel(context=self).get_dict_list()

        return self.reponse_json_success(marketing_program_list)


class ActTypeListHandler(SevenBaseHandler):
    """
    :description: 活动类型列表
    """
    def get_async(self):
        """
        :description: 活动类型获取
        :param marketing_id：营销方案id
        :param is_act：该活动类型是否创建过活动
        :return: 列表
        :last_editors: HuangJingCan
        """
        is_act = int(self.get_param("is_act", 0))
        app_id = self.get_param("app_id")

        marketing_id = int(self.get_param("marketing_id", 0))
        condition = ""
        if marketing_id > 0:
            condition = "marketing_id LIKE '%," + str(marketing_id) + ",%'"

        act_type_list = ActTypeModel(context=self).get_list(condition)

        new_list = []

        for info in act_type_list:
            info.play_process = self.json_loads(info.play_process) if info.play_process else {}
            info.applicable_behavior = self.json_loads(info.applicable_behavior) if info.applicable_behavior else {}
            info.market_function = self.json_loads(info.market_function) if info.market_function else {}
            info.skill_case = self.json_loads(info.skill_case) if info.skill_case else []
            info.type_desc = self.json_loads(info.type_desc) if info.type_desc else []
            info.share_desc = self.json_loads(info.share_desc) if info.share_desc else {}
            info.rule_desc = self.json_loads(info.rule_desc) if info.rule_desc else []
            info.integral_rule = self.json_loads(info.integral_rule) if info.integral_rule else []
            info.act_id = 0
            if is_act > 0 and app_id:
                act_dict = ActInfoModel(context=self).get_dict("app_id=%s and act_type=%s", params=[app_id, info.id])
                if act_dict:
                    info.act_id = act_dict['id']

            new_list.append(info.__dict__)

        return self.reponse_json_success(new_list)


class ActCreateHandler(SevenBaseHandler):
    """
    :description: 创建活动
    """
    @filter_check_params("act_type,app_id")
    def get_async(self):
        """
        :description: 创建活动
        :param app_id：app_id
        :param act_type：活动类型
        :param act_name：活动名称
        :param theme_id：主题id
        :return act_id
        :last_editors: HuangJingCan
        """
        owner_open_id = self.get_taobao_param().open_id
        app_id = self.get_param("app_id")
        act_name = self.get_param("act_name")
        act_type = int(self.get_param("act_type", 1))
        theme_id = int(self.get_param("theme_id", 1))
        now_datetime = self.get_now_datetime()

        base_info = BaseInfoModel(context=self).get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")
        theme_info = ThemeInfoModel(context=self).get_entity()
        if not theme_info:
            return self.reponse_json_error("NoTheme", "请管理员先上传主题信息")
        skin_info = SkinInfoModel(context=self).get_entity("theme_id=%s", params=theme_info.id)
        if not skin_info:
            return self.reponse_json_error("NoSkin", "请管理员先上传皮肤信息")
        act_type_info = ActTypeModel(context=self).get_entity("id=%s", params=act_type)
        if not act_type_info:
            return self.reponse_json_error("NoActType", "无活动类型信息")

        #增加默认活动
        act_info_model = ActInfoModel(context=self)
        act_count = act_info_model.get_total("app_id=%s", params=app_id)

        act_info = ActInfo()
        act_info.app_id = app_id
        act_info.owner_open_id = owner_open_id
        act_info.act_name = base_info.product_name + "_" + str(act_count + 1)
        act_info.act_type = act_type
        act_info.theme_id = theme_info.id
        act_info.close_word = "抱歉，程序维护中"
        act_info.share_desc = self.json_dumps(act_type_info.share_desc) if act_type_info.share_desc else {}
        act_info.rule_desc = self.json_dumps(act_type_info.rule_desc) if act_type_info.rule_desc else []
        act_info.integral_rule = self.json_dumps(act_type_info.integral_rule) if act_type_info.integral_rule else []
        act_info.start_date = now_datetime
        act_info.end_date = "2900-01-01 00:00:00"
        act_info.refund_count = 0
        act_info.is_black = 0
        act_info.sort_index = 0
        act_info.is_release = 1
        act_info.join_ways = 0
        act_info.is_fictitious = 0
        act_info.currency_type = act_type_info.currency_type
        act_info.task_currency_type = act_type_info.task_currency_type
        act_info.lottery_value = 0
        act_info.release_date = now_datetime
        act_info.create_date = now_datetime
        act_info.modify_date = now_datetime

        act_info.id = act_info_model.add_entity(act_info)

        self.create_operation_log(OperationType.add.value, act_info.__str__(), "ActCreateHandler", None, self.json_dumps(act_info))

        return self.reponse_json_success(act_info.id)


class ActHandler(SevenBaseHandler):
    """
    :description: 修改活动
    """
    @filter_check_params("act_id,act_name")
    def post_async(self):
        """
        :description: 修改活动
        :param act_id：活动id
        :param act_name：活动名称
        :param theme_id：主题ID
        :param store_url：店铺地址
        :param close_word：关闭小程序文案
        :param share_desc：分享内容
        :param rule_desc：规则内容
        :param integral_rule：积分规则
        :param start_date：开始时间
        :param end_date：结束时间
        :param refund_count：退款次数
        :param is_black：是否开启黑名单
        :param sort_index：排序号
        :param is_release：是否发布（1是0否）
        :param join_ways：活动参与条件（0所有1关注店铺2加入会员）
        :param is_fictitious：是否开启虚拟中奖
        :param currency_type 抽奖货币类型（0无1次数2积分3价格档位4抽奖码）
        :param lottery_value 单次抽奖消耗次数（积分）
        :return act_id
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))
        act_name = self.get_param("act_name")
        theme_id = int(self.get_param("theme_id", 1))
        store_url = self.get_param("store_url")
        close_word = self.get_param("close_word", "抱歉，程序维护中")
        share_desc = self.get_param("share_desc")
        rule_desc = self.get_param("rule_desc")
        integral_rule = self.get_param("integral_rule")
        start_date = self.get_param("start_date")
        end_date = self.get_param("end_date")
        refund_count = int(self.get_param("refund_count", 0))
        is_black = int(self.get_param("is_black", 0))
        sort_index = int(self.get_param("sort_index", 1))
        is_release = int(self.get_param("is_release", 0))
        join_ways = int(self.get_param("join_ways", 0))
        is_fictitious = int(self.get_param("is_fictitious", 0))
        lottery_value = int(self.get_param("lottery_value", 0))

        act_info_model = ActInfoModel(context=self)
        act_info = act_info_model.get_entity_by_id(act_id)

        if not act_info:
            return self.reponse_json_error("NoAct", "对不起，找不到该活动")

        old_act_info = deepcopy(act_info)

        act_info.act_name = act_name
        act_info.theme_id = theme_id
        act_info.store_url = store_url
        act_info.close_word = close_word
        act_info.share_desc = share_desc if share_desc != "" else {}
        act_info.rule_desc = rule_desc if rule_desc != "" else []
        act_info.integral_rule = integral_rule if integral_rule != "" else []
        act_info.start_date = start_date if start_date else self.get_now_datetime()
        act_info.end_date = end_date if end_date else "2900-01-01 00:00:00"
        act_info.refund_count = refund_count
        act_info.is_black = is_black
        act_info.sort_index = sort_index
        act_info.is_release = is_release
        act_info.join_ways = join_ways
        act_info.is_fictitious = is_fictitious
        act_info.lottery_value = lottery_value
        act_info.modify_date = self.get_now_datetime()

        act_info_model.update_entity(act_info)

        self.create_operation_log(OperationType.update.value, act_info.__str__(), "ActHandler", self.json_dumps(old_act_info), self.json_dumps(act_info))

        return self.reponse_json_success()


class ActListHandler(SevenBaseHandler):
    """
    :description: 活动列表
    """
    def get_async(self):
        """
        :description: 获取活动列表
        :param act_name：活动名称
        :param page_index：页索引
        :param page_size：页大小
        :return: PageInfo
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 10))
        is_del = int(self.get_param("is_del", 0))
        act_name = self.get_param("act_name")
        app_id = self.get_app_id()

        if app_id:
            order_by = "id ASC"
            condition = "app_id=%s"
            if is_del == 0:
                condition += "AND is_del=0"
            else:
                condition += "AND is_del=1"

            page_list, total = ActInfoModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", order_by, app_id)

            for page in page_list:
                page["share_desc"] = self.json_loads(page["share_desc"]) if page["share_desc"] else {}
                page["rule_desc"] = self.json_loads(page["rule_desc"]) if page["rule_desc"] else []
                page["menu_configed"] = self.json_loads(page["menu_configed"]) if page["menu_configed"] else []
                page["online_url"] = self.get_online_url(page['id'], app_id)
                page["live_url"] = self.get_live_url(app_id)
                page["finish_status"] = page["finish_progress"]

            page_info = PageInfo(page_index, page_size, total, page_list)

            return self.reponse_json_success(page_info)

        return self.reponse_json_success({"data": []})


class ActInfoHandler(SevenBaseHandler):
    """
    :description: 活动信息获取
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 活动信息获取
        :param act_id：活动id
        :return: 活动信息
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))

        act_info = ActInfoModel(context=self).get_dict_by_id(act_id)

        if act_info:
            act_info['share_desc'] = self.json_loads(act_info['share_desc']) if act_info['share_desc'] != "" else {}
            act_info['rule_desc'] = self.json_loads(act_info['rule_desc']) if act_info['rule_desc'] != "" else []
            act_info['menu_configed'] = self.json_loads(act_info['menu_configed']) if act_info['menu_configed'] != "" else []
            act_info['online_url'] = self.get_online_url(act_info['id'], act_info['app_id'])
            act_info['live_url'] = self.get_live_url(act_info['app_id'])

            return self.reponse_json_success(act_info)

        return self.reponse_json_success()


class ActDelHandler(SevenBaseHandler):
    """
    :description: 删除或者还原活动
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 删除或者还原活动
        :param act_id：活动id
        :param is_del：0-还原，1-删除
        :return: 
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))
        is_del = int(self.get_param("is_del", 1))
        modify_date = self.get_now_datetime()

        if act_id <= 0:
            return self.reponse_json_error_params()

        is_release = 0 if is_del == 1 else 1

        ActInfoModel(context=self).update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, act_id])

        return self.reponse_json_success()


class ActReleaseHandler(SevenBaseHandler):
    """
    :description: 上架下架活动
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 上架下架活动
        :param act_id：活动id
        :return 
        :last_editors: LaiKaiXiang
        """
        act_id = self.get_param("act_id")
        is_release = int(self.get_param("is_release", 0))
        modify_date = self.get_now_datetime()

        ActInfoModel(context=self).update_table("modify_date=%s,is_release=%s", "id=%s", [modify_date, is_release, act_id])

        return self.reponse_json_success()


class ActQrCodeHandler(SevenBaseHandler):
    """
    :description: 活动二维码获取
    """
    @filter_check_params("url")
    def get_async(self):
        """
        :description: 活动二维码获取
        :param act_id：活动id
        :return: 活动二维码图片
        :last_editors: HuangJingCan
        """
        url = self.get_param("url")

        img, img_bytes = QRCodeHelper.create_qr_code(url, fill_color="black")
        img_base64 = base64.b64encode(img_bytes).decode()

        return self.reponse_json_success(f"data:image/jpeg;base64,{img_base64}")


class ActReviewHandler(SevenBaseHandler):
    """
    :description: 还原活动
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 还原活动
        :param act_id：活动id
        :return 
        :last_editors: HuangJingCan
        """
        act_id = self.get_param("act_id")
        modify_date = self.get_now_datetime()

        app_id = self.get_app_id()

        if not app_id:
            return self.reponse_json_error("NoAppId", "对不起，app_id不存在")

        act_info_model = ActInfoModel(context=self)
        act_info_total = act_info_model.get_total("app_id=%s and is_del=0", params=app_id)
        if act_info_total > 9:
            return self.reponse_json_error("OverAct", "对不起，活动不可超过10个")

        act_info_model.update_table("is_del=0,modify_date=%s,is_release=1", "id=%s", [modify_date, act_id])

        return self.reponse_json_success()


class NextProgressHandler(SevenBaseHandler):
    """
    :description: 下一步
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 下一步
        :param act_id：活动id
        :param finish_key：finish_key
        :return 
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))
        finish_key = self.get_param("finish_key")

        base_info = BaseInfoModel(context=self).get_entity()
        if not base_info:
            return self.reponse_json_error("Error", "对不起，请与管理员联系")

        act_info_model = ActInfoModel(context=self)
        act_info = act_info_model.get_dict_by_id(act_id)
        if not act_info:
            return self.reponse_json_error("NoAct", "对不起，找不到当前活动")

        menu_config = self.json_loads(base_info.menu_config)
        menu = [menu for menu in menu_config if menu["key"] == finish_key]
        if len(menu) == 0:
            return self.reponse_json_error("Error", "对不起，无此菜单")

        if act_info["menu_configed"] != "" and finish_key in act_info["menu_configed"]:
            return self.reponse_json_success()

        if act_info["menu_configed"] == "":
            act_info["menu_configed"] = "[]"

        menu_configed = self.json_loads(act_info["menu_configed"])
        menu_configed.append(finish_key)

        result_menu_configed = []
        for item in menu_configed:
            is_exist = [item2 for item2 in menu_config if item2["key"] == item]
            if len(is_exist) > 0:
                result_menu_configed.append(item)

        finish_progress = 0
        if finish_key == "finish_config" and act_info["finish_progress"] == 0:
            finish_progress = 1

        result_menu_configed = self.json_dumps(result_menu_configed)

        act_info_model.update_table("menu_configed=%s,finish_progress=%s", "id=%s", [result_menu_configed, finish_progress, act_id])

        if finish_progress == 1:
            app_id = self.get_app_id()
            if app_id:
                AppInfoModel(context=self).update_table("is_setting=1", "app_id=%s", app_id)

        return self.reponse_json_success()


# -*- coding: utf-8 -*-
"""
:Author: CaiYouBin
:Date: 2020-06-12 11:04:12
:LastEditTime: 2021-04-16 14:24:12
:LastEditors: HuangJingCan
:description: 
"""
from seven_cloudapp.handlers.seven_base import *

from aliyunsdkcore.client import AcsClient
from aliyunsdkcore.request import CommonRequest


class SendSmsHandler(SevenBaseHandler):
    """
    :description: 发送短信
    """
    def get_async(self):
        """
        :description: 发送短信
        :param thelephone：电话号码
        :return 
        :last_editors: HuangJingCan
        """
        open_id = self.get_taobao_param().open_id
        thelephone = self.get_param("thelephone")
        client = AcsClient('LTAI4FwMYR1FBBui21t7cyh7', 'zyTM5zpYcL8lMXwtDgVoCfHgndoSKi', 'cn-hangzhou')

        result_code = str(random.randint(100000, 999999))
        request = CommonRequest()
        request.set_accept_format('json')
        request.set_domain('dysmsapi.aliyuncs.com')
        request.set_method('POST')
        request.set_protocol_type('https')  # https | http
        request.set_version('2017-05-25')
        request.set_action_name('SendSms')

        request.add_query_param('RegionId', "cn-hangzhou")
        request.add_query_param('PhoneNumbers', thelephone)
        request.add_query_param('SignName', "天志互联")
        request.add_query_param('TemplateCode', "SMS_193145309")
        request.add_query_param('TemplateParam', "{\"code\":" + result_code + "}")

        response = client.do_action(request)

        result = dict(json.loads(response))
        result["result_code"] = result_code
        #记录验证码
        self.redis_init().set("user_" + open_id + "_bind_phone_code", result_code, ex=300)

        return self.reponse_json_success()


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-24 17:26:33
:LastEditTime: 2021-04-16 10:41:24
:LastEditors: HuangJingCan
:description: 基础信息相关
"""
from seven_cloudapp.handlers.top_base import *

from seven_cloudapp.models.db_models.base.base_info_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *
from seven_cloudapp.models.db_models.saas.saas_custom_model import *
from seven_cloudapp.models.db_models.product.product_price_model import *


class LeftNavigationHandler(TopBaseHandler):
    """
    :description: 左侧导航栏
    """
    def get_async(self):
        """
        :description: 左侧导航栏
        :param {*}
        :return 字典
        :last_editors: HuangJingCan
        """
        user_nick = self.get_taobao_param().user_nick
        if not user_nick:
            return self.reponse_json_error("Error", "对不起,请先授权登录")
        store_user_nick = user_nick.split(':')[0]
        if not store_user_nick:
            return self.reponse_json_error("Error", "对不起，请先授权登录")
        base_info = BaseInfoModel(context=self).get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")

        app_info = None
        app_id = self.get_param("app_id")
        if app_id:
            app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)

        # 左上角信息
        info = {}
        info["company"] = "天志互联"
        info["miniappName"] = base_info.product_name
        info["logo"] = base_info.product_icon

        # 左边底部菜单
        helper_info = {}
        # 钉钉号
        # helper_info["customer_service"] = "http://amos.alicdn.com/getcid.aw?v=2&uid=%E5%A4%A9%E5%BF%97%E4%BA%92%E8%81%94&site=cntaobao&s=1&groupid=0&charset=utf-8"
        helper_info["customer_service"] = base_info.customer_service
        helper_info["video_url"] = base_info.video_url
        helper_info["study_url"] = base_info.study_url
        helper_info["is_remind_phone"] = base_info.is_remind_phone
        helper_info["phone"] = ""

        # 过期时间
        renew_info = {}
        renew_info["surplus_day"] = 0
        dead_date = ""
        if app_info:
            helper_info["phone"] = app_info.app_telephone
            dead_date = app_info.expiration_date
        else:
            dead_date = self.get_dead_date(store_user_nick)
        renew_info["dead_date"] = dead_date
        if dead_date != "expire":
            renew_info["surplus_day"] = TimeHelper.difference_days(dead_date, self.get_now_datetime())

        data = {}
        data["app_info"] = info
        data["helper_info"] = helper_info
        data["renew_info"] = renew_info
        if base_info.product_price:
            data["renew_prices"] = self.json_loads(base_info.product_price)

        product_price = ProductPriceModel(context=self).get_entity("is_release=1")
        if product_price and product_price.content:
            begin_time = TimeHelper.format_time_to_datetime(product_price.begin_time)
            end_time = TimeHelper.format_time_to_datetime(product_price.end_time)
            this_time = TimeHelper.get_now_datetime()
            if this_time >= begin_time and this_time <= end_time:
                data["renew_prices"] = self.json_loads(product_price.content)

        return self.reponse_json_success(data)


class RightExplainHandler(SevenBaseHandler):
    """
    :description: 右侧各种教程和说明导航
    """
    def get_async(self):
        """
        :description: 右侧各种教程和说明导航
        :param {*}
        :return dict
        :last_editors: HuangJingCan
        """
        base_info = BaseInfoModel(context=self).get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")

        data = []

        if base_info.course_strategy:
            data = self.json_loads(base_info.course_strategy)

        return self.reponse_json_success(data)


class FriendLinkHandler(SevenBaseHandler):
    """
    :description: 获取友情链接
    """
    def get_async(self):
        """
        :description: 获取友情链接
        :param {*}
        :return list
        :last_editors: HuangJingCan
        """
        base_info = BaseInfoModel(context=self).get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")

        data = []

        if base_info.friend_link:
            data = self.json_loads(base_info.friend_link)

        return self.reponse_json_success(data)


class UpdateInfoHandler(SevenBaseHandler):
    """
    :description: 获取更新信息
    """
    @filter_check_params("app_id")
    def get_async(self):
        """
        :description: 获取更新信息
        :param app_id：app_id
        :return dict
        :last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")

        base_info = BaseInfoModel(context=self).get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")
        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("AppInfoError", "App信息出错")

        data = {}

        data["client_ver"] = base_info.client_ver
        #指定账号升级
        test_client_ver = config.get_value("test_client_ver")
        if test_client_ver:
            user_nick = self.get_taobao_param().user_nick
            if user_nick:
                if user_nick == config.get_value("test_user_nick"):
                    data["client_ver"] = test_client_ver

        data["server_ver"] = base_info.server_ver
        data["client_now_ver"] = app_info.template_ver
        data["is_force_update"] = base_info.is_force_update
        data["update_function"] = []
        if base_info.update_function:
            data["update_function"] = self.json_loads(base_info.update_function)
        data["update_function_b"] = []
        if base_info.update_function_b:
            data["update_function_b"] = self.json_loads(base_info.update_function_b)

        return self.reponse_json_success(data)


class OnlineLiveUrlHandler(SevenBaseHandler):
    """
    :description: 小程序链接
    """
    @filter_check_params("app_id,act_id")
    def get_async(self):
        """
        :description: 小程序链接
        :param app_id：app_id
        :param act_id：活动id
        :return dict
        :last_editors: HuangJingCan
        """
        app_id = self.get_param("app_id")
        act_id = int(self.get_param("act_id", 0))

        if act_id <= 0:
            return self.reponse_json_error("ActError", "无效活动")

        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("AppInfoError", "App信息出错")

        data = {}

        data["online_url"] = self.get_online_url(act_id, app_id)
        data["live_url"] = self.get_live_url(app_id)

        return self.reponse_json_success(data)


class DecorationPosterHandler(SevenBaseHandler):
    """
    :description: 装修海报
    """
    def get_async(self):
        """
        :description: 装修海报
        :param {*}
        :return dict
        :last_editors: HuangJingCan
        """
        base_info = BaseInfoModel(context=self).get_entity()
        if not base_info:
            return self.reponse_json_error("BaseInfoError", "基础信息出错")

        data = {}

        if base_info.decoration_poster:
            data["decoration_poster"] = self.json_loads(base_info.decoration_poster)

        return self.reponse_json_success(data)


class SaasCustomHandler(SevenBaseHandler):
    """
    :description: saas定制化信息获取
    """
    def get_async(self):
        """
        :description: saas定制化信息获取
        :param {*}
        :return int
        :last_editors: HuangJingCan
        """
        user_nick = self.get_taobao_param().user_nick
        if not user_nick:
            return self.reponse_json_success(0)
        store_user_nick = user_nick.split(':')[0]
        if not store_user_nick:
            return self.reponse_json_success(0)

        cloud_app_id = 0
        saas_custom = SaasCustomModel(context=self).get_entity("store_user_nick=%s AND is_release=1", params=store_user_nick)
        if saas_custom:
            cloud_app_id = saas_custom.cloud_app_id

        return self.reponse_json_success(cloud_app_id)


class OperateLoginHandler(SevenBaseHandler):
    """
    :description: 根据店铺名称获取app_id
    """
    @filter_check_params("store_name")
    def get_async(self):
        """
        :description: 根据店铺名称获取app_id
        :param store_name:店铺名称
        :return str
        :last_editors: HuangJingCan
        """
        store_name = self.get_param("store_name")

        app_info = AppInfoModel(context=self).get_dict("store_name=%s", params=store_name)

        app_id = ""
        if app_info:
            app_id = app_info["app_id"]

        return self.reponse_json_success(app_id)


# -*- coding: utf-8 -*-
"""
:Author: CaiYouBin
:Date: 2020-05-28 14:50:27
:LastEditTime: 2021-02-07 10:04:49
:LastEditors: HuangJingCan
:description: 商品相关
"""
from seven_cloudapp.handlers.top_base import *

from seven_cloudapp.models.db_models.prize.prize_roster_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *
from seven_cloudapp.models.db_models.recommend.recommend_goods_model import *


class SubmitSkuHandler(SevenBaseHandler):
    """
    :description: 提交SKU
    """
    @filter_check_params("sku_id")
    def get_async(self):
        """
        :description: 提交SKU
        :param user_prize_id：用户中奖信息id
        :param properties_name：sku属性
        :param sku_id：sku_id
        :return 
        :last_editors: HuangJingCan
        """
        app_id = self.get_taobao_param().source_app_id
        open_id = self.get_taobao_param().open_id

        user_prize_id = int(self.get_param("user_prize_id"))
        properties_name = self.get_param("properties_name")
        sku_id = self.get_param("sku_id")

        prize_roster_model = PrizeRosterModel(context=self)
        prize_roster = prize_roster_model.get_entity("id=%s", params=user_prize_id)
        if not prize_roster:
            return self.reponse_json_error("NoUserPrize", "对不起，找不到该奖品")
        if prize_roster.is_sku > 0:
            goods_code_list = self.json_loads(prize_roster.goods_code_list)
            goods_codes = [i for i in goods_code_list if str(i["sku_id"]) == sku_id]

            prize_roster.sku_id = sku_id
            prize_roster.properties_name = properties_name
            if goods_codes and ("goods_code" in goods_codes[0].keys()):
                prize_roster.goods_code = goods_codes[0]["goods_code"]

        prize_roster_model.update_entity(prize_roster)

        return self.reponse_json_success()


class SkuInfoHandler(TopBaseHandler):
    """
    :description: 获取SKU信息
    """
    def get_async(self):
        """
        :description: 获取SKU信息
        :param num_iids：num_iids
        :return
        :last_editors: HuangJingCan
        """
        app_id = self.get_taobao_param().source_app_id
        num_iids = self.get_param("num_iids")

        access_token = ""
        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if app_info:
            access_token = app_info.access_token

        return self.get_sku_info(num_iids, access_token)


class GoodsListHandler(TopBaseHandler):
    """
    :description: 获取商品列表
    """
    def get_async(self):
        """
        :description: 获取商品列表
        :param page_index：页索引
        :param page_size：页大小
        :return: 
        :last_editors: HuangJingCan
        """
        app_id = self.get_taobao_param().source_app_id
        page_index = int(self.get_param("page_index", 0))
        page_size = self.get_param("page_size", 200)

        access_token = ""
        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if app_info:
            access_token = app_info.access_token

        return self.get_goods_list_client(page_index, page_size, access_token)


class RecommandGoodsHandler(SevenBaseHandler):
    """
    :description: 获取推荐商品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取推荐商品列表
        :param act_id：活动id
        :return: list
        :last_editors: HuangJianYi
        """
        act_id = int(self.get_param("act_id", 0))

        if act_id <= 0:
            return self.reponse_json_error_params()

        recommend_goods = RecommendGoodsModel(context=self).get_entity("act_id=%s", params=act_id)

        if not recommend_goods:
            return self.reponse_json_success([])
        if recommend_goods.is_release == 0:
            return self.reponse_json_success([])

        return self.reponse_json_success(self.json_loads(recommend_goods.goods_list))


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-11-05 10:13:31
:LastEditTime: 2021-04-16 16:15:17
:LastEditors: HuangJingCan
:description: 奖品相关
"""
from seven_cloudapp.handlers.top_base import *

from seven_cloudapp.models.seven_model import PageInfo
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.act.act_prize_model import *
from seven_cloudapp.models.db_models.pay.pay_order_model import *
from seven_cloudapp.models.db_models.prize.prize_roster_model import *
from seven_cloudapp.models.db_models.prize.prize_order_model import *


class PrizeListHandler(SevenBaseHandler):
    """
    :description: 奖品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description:  获取奖品列表
        :param act_id：活动id
        :param machine_id：机台id
        :param page_index：页索引
        :param page_size：页大小
        :return: 分页列表信息
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))
        act_id = int(self.get_param("act_id", 0))
        machine_id = int(self.get_param("machine_id", 0))
        ascription_type = int(self.get_param("ascription_type", 0))

        condition = "is_release=1 AND act_id=%s AND ascription_type=%s"
        params = [act_id, ascription_type]

        if machine_id > 0:
            condition += " AND machine_id=%s"
            params.append(machine_id)

        act_prize_page_list, total = ActPrizeModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="sort_index desc", params=params)

        # for act_prize in act_prize_page_list:
        #     try:
        #         act_prize["prize_detail"] = self.json_loads(act_prize["prize_detail"]) if act_prize["prize_detail"] else []
        #     except Exception as ex:
        #         self.logging_link_error(traceback.format_exc())
        #         act_prize["prize_detail"] = []

        page_info = PageInfo(page_index, page_size, total, act_prize_page_list)

        return self.reponse_json_success(page_info)


class AllPrizeListHandler(SevenBaseHandler):
    """
    :description: 所有奖品列表
    """
    @filter_check_params("act_id,machine_id")
    def get_async(self):
        """
        :description:  所有奖品列表
        :param act_id:活动id
        :param machine_id:机台id
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_taobao_param().source_app_id
        open_id = self.get_taobao_param().open_id
        act_id = int(self.get_param("act_id", 0))
        machine_id = int(self.get_param("machine_id", 0))

        condition = "is_release=1 AND act_id=%s AND machine_id=%s"

        act_prize_list = ActPrizeModel(context=self).get_dict_list(condition, params=[act_id, machine_id])

        for act_prize in act_prize_list:
            try:
                act_prize["prize_detail"] = self.json_loads(act_prize["prize_detail"]) if act_prize["prize_detail"] else []
            except Exception as ex:
                act_prize["prize_detail"] = []

        return self.reponse_json_success(act_prize_list)


class UserPrizeListHandler(SevenBaseHandler):
    """
    :description: 获取用户奖品列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取用户奖品列表
        :param act_id：活动id
        :return status：状态
        :param page_index：页索引
        :param page_size：页大小
        :return: 
        :last_editors: HuangJingCan
        """
        app_id = self.get_taobao_param().source_app_id
        open_id = self.get_taobao_param().open_id
        act_id = int(self.get_param("act_id", 0))
        status = int(self.get_param("status", 0))
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))

        condition = "open_id=%s and act_id=%s"
        params = [open_id, act_id]
        order_by = "id desc"

        if status == 0:
            condition += " and prize_order_id=0"
        else:
            condition += " and prize_order_id>0"

        page_list, total = PrizeRosterModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", order_by, params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


class SubmitPrizeOrderHandler(SevenBaseHandler):
    """
    :description: 奖品订单提交
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 奖品订单提交
        :param act_id：活动id
        :param login_token：登录令牌
        :param real_name：用户名
        :param telephone：联系电话
        :param province：所在省
        :param city：所在市
        :param county：所在区
        :param street：所在街道
        :param address：收货地址
        :return 
        :last_editors: HuangJingCan
        """
        app_id = self.get_taobao_param().source_app_id
        open_id = self.get_taobao_param().open_id

        act_id = int(self.get_param("act_id", 0))
        login_token = self.get_param("login_token")
        real_name = self.get_param("real_name")
        telephone = self.get_param("telephone")
        province = self.get_param("province")
        city = self.get_param("city")
        county = self.get_param("county")
        street = self.get_param("street")
        address = self.get_param("address")

        user_info = UserInfoModel(context=self).get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
        if not user_info:
            return self.reponse_json_error("NoUser", "对不起，用户不存在")
        if user_info.user_state == 1:
            return self.reponse_json_error("UserBlock", "对不起，你是黑名单用户,无法提交订单")
        if user_info.login_token != login_token:
            return self.reponse_json_error("ErrorLoginToken", "对不起，帐号已在另一台设备登录,当前无法提交订单")

        act_info_model = ActInfoModel(context=self)
        act_info = act_info_model.get_entity("id=%s and is_del=0 and is_release=1", params=act_id)
        if not act_info:
            return self.reponse_json_error("NoAct", "对不起，活动不存在")

        prize_roster_model = PrizeRosterModel(context=self)
        prize_roster_count = prize_roster_model.get_total("act_id=%s and open_id=%s and prize_order_id=0", params=[act_id, open_id])
        if prize_roster_count == 0:
            return self.reponse_json_error("NoNeedSubmitPrize", "当前没有未提交订单的奖品")

        prize_order_model = PrizeOrderModel(context=self)
        prize_order = PrizeOrder()
        prize_order.app_id = app_id
        prize_order.open_id = open_id
        prize_order.act_id = act_id
        prize_order.user_nick = user_info.user_nick
        prize_order.real_name = real_name
        prize_order.telephone = telephone
        prize_order.province = province
        prize_order.city = city
        prize_order.county = county
        prize_order.street = street
        prize_order.adress = address
        prize_order.create_date = self.get_now_datetime()
        prize_order.modify_date = self.get_now_datetime()
        prize_order.order_no = self.create_order_id()

        prize_order.id = prize_order_model.add_entity(prize_order)

        update_sql = "prize_order_id=%s,prize_order_no=%s"
        where = "act_id=%s and open_id=%s and prize_order_id=0"
        params = [prize_order.id, prize_order.order_no, act_id, open_id]
        prize_roster_model.update_table(update_sql, where, params)

        return self.reponse_json_success()


class PrizeOrderHandler(SevenBaseHandler):
    """
    :description: 用户订单列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 用户订单列表
        :param act_id：活动id
        :param page_index：页索引
        :param page_size：页大小
        :return: PageInfo
        :last_editors: HuangJingCan
        """
        app_id = self.get_taobao_param().source_app_id
        open_id = self.get_taobao_param().open_id
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))
        act_id = int(self.get_param("act_id", 0))
        prize_order_id = int(self.get_param("prize_order_id", 0))

        condition = "open_id=%s and act_id=%s"
        params = [open_id, act_id]

        if prize_order_id > 0:
            condition += " and id=%s"
            params.append(prize_order_id)

        prize_order_model = PrizeOrderModel(context=self)
        prize_roster_model = PrizeRosterModel(context=self)
        prize_order_list_dict, total = prize_order_model.get_dict_page_list("*", page_index, page_size, condition, "", "create_date desc", params)
        if prize_order_list_dict:
            prize_order_id_list = [str(i['id']) for i in prize_order_list_dict]
            prize_order_ids = ",".join(prize_order_id_list)
            prize_roster_list_dict = prize_roster_model.get_dict_list("prize_order_id in (" + prize_order_ids + ")")
            for i in range(len(prize_order_list_dict)):
                prize_list = [prize_roster for prize_roster in prize_roster_list_dict if prize_order_list_dict[i]["id"] == prize_roster["prize_order_id"]]
                prize_order_list_dict[i]["prize_list"] = prize_list

        page_info = PageInfo(page_index, page_size, total, prize_order_list_dict)

        return self.reponse_json_success(page_info)


class RosterNoticeHandler(SevenBaseHandler):
    """
    :description: 中奖通告
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 中奖通告
        :param act_id：活动id
        :return 列表
        :last_editors: HuangJingCan
        """
        act_id = int(self.get_param("act_id", 0))

        prize_roster_list_dict = PrizeRosterModel(context=self).get_dict_list("act_id=%s", order_by="id desc", limit="20", params=act_id)

        return self.reponse_json_success(prize_roster_list_dict)


class GetCouponPrizeHandler(TopBaseHandler):
    """
    :description: 领取优惠券（发奖接口）
    """
    @filter_check_params("user_prize_id")
    def get_async(self):
        """
        :description: 领取优惠券（发奖接口）
        :param user_prize_id:用户奖品标识
        :return: 
        :last_editors: HuangJianYi
        """
        app_id = self.get_taobao_param().source_app_id
        open_id = self.get_taobao_param().open_id
        user_prize_id = int(self.get_param("user_prize_id", 0))
        # self.logging_link_error("Error【优惠券传参user_prize_id】"+ str(user_prize_id))
        app_info = AppInfoModel(context=self).get_entity("app_id=%s", params=app_id)
        if not app_info:
            return self.reponse_json_error("NoApp", "对不起，小程序不存在")
        access_token = app_info.access_token
        if access_token == "":
            return self.reponse_json_error("Error", "未授权，请联系客服授权")

        prize_roster_model = PrizeRosterModel(context=self)
        prize_roster = prize_roster_model.get_dict_by_id(user_prize_id)
        if not prize_roster or prize_roster['open_id'] != open_id:
            return self.reponse_json_error("Error", "对不起,奖品不存在")

        act_prize_model = ActPrizeModel(context=self)
        act_prize = act_prize_model.get_dict_by_id(prize_roster['prize_id'])
        if not act_prize or act_prize['right_ename'] == "" or prize_roster['right_ename'] == "":
            return self.reponse_json_error("Error", "对不起,奖品不是优惠券,无需领取")

        resp = self.benefit_send(act_prize['right_ename'], open_id, access_token)
        # self.logging_link_error("Error【优惠券】"+ str(resp))
        if not resp:
            return self.reponse_json_error("Error", "领取失败")

        if resp["alibaba_benefit_send_response"]:
            if resp["alibaba_benefit_send_response"]["result_success"] == True:
                prize_roster_model.update_table("order_status=2", "id=%s", params=[user_prize_id])
                result = {}
                result["prize_name"] = resp["alibaba_benefit_send_response"]["prize_name"]
                return self.reponse_json_success(result)
            if resp["alibaba_benefit_send_response"]["result_code"] == "COUPON_INVALID_OR_DELETED":
                prize_roster_model.update_table("order_status=2", "id=%s", params=[user_prize_id])
                return self.reponse_json_error("Error", "领取失败：优惠券无效或已删除")
            if resp["alibaba_benefit_send_response"]["result_code"] == "APPLY_SINGLE_COUPON_COUNT_EXCEED_LIMIT":
                return self.reponse_json_error("Error", "领取失败：优惠券超过限额")
            if resp["alibaba_benefit_send_response"]["result_code"] == "USER_PERMISSION_EXCEED_MAX_RIGHT_COUNT_IN_DAY":
                return self.reponse_json_error("Error", "领取失败：同一张优惠券每天限领取一次")
            if resp["alibaba_benefit_send_response"]["result_code"] == "APPLY_ONE_SELLER_COUNT_EXCEED_LIMIT":
                return self.reponse_json_error("Error", "领取失败：用户优惠券超出10张限制")
        else:
            result = resp["sub_msg"] if resp["sub_msg"] else ""
            if result == "" and resp["result_msg"]:
                result = resp["result_msg"]
            return self.reponse_json_error("Error", f"领取失败:{result}")


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2020-05-12 20:04:54
:LastEditTime: 2021-06-08 15:36:26
:LastEditors: HuangJingCan
:description: 用户相关
"""
from seven_cloudapp.handlers.seven_base import *
from seven_cloudapp.libs.customize.oss2help import *

from seven_cloudapp.models.enum import *
from seven_cloudapp.models.seven_model import *
from seven_cloudapp.models.db_models.app.app_info_model import *
from seven_cloudapp.models.db_models.login.login_log_model import *
from seven_cloudapp.models.db_models.user.user_info_model import *
from seven_cloudapp.models.db_models.machine.machine_value_model import *
from seven_cloudapp.models.db_models.user.user_blacklist_model import *
from seven_cloudapp.models.db_models.lottery.lottery_value_log_model import *
from seven_cloudapp.models.db_models.act.act_info_model import *
from seven_cloudapp.models.db_models.coin.coin_order_model import *
from seven_cloudapp.models.db_models.prop.prop_log_model import *
from seven_cloudapp.models.db_models.user.user_detail_model import *


class LoginHandler(SevenBaseHandler):
    """
    :description: 登录处理
    """
    @filter_check_params("open_id")
    def get_async(self):
        """
        :description: 登录日志入库
        :param open_id：用户唯一标识
        :param user_nick：用户昵称
        :return: 
        :last_editors: HuangJingCan
        """
        open_id = self.get_taobao_param().open_id
        user_nick = self.get_taobao_param().user_nick

        request_params = str(self.request_params)

        if user_nick == "":
            return self.reponse_json_success()

        login_log_model = LoginLogModel(context=self)
        login_log = login_log_model.get_entity("open_id=%s", params=open_id)

        is_add = False
        if not login_log:
            is_add = True
            login_log = LoginLog()

        login_log.open_id = open_id
        login_log.user_nick = user_nick
        if user_nick.__contains__(":"):
            login_log.store_user_nick = user_nick.split(":")[0]
            login_log.is_master = 0
        else:
            login_log.store_user_nick = user_nick
            login_log.is_master = 1
        login_log.request_params = request_params
        login_log.modify_date = self.get_now_datetime()

        try:
            if is_add:
                login_log.create_date = login_log.modify_date
                login_log.id = login_log_model.add_entity(login_log)
            else:
                login_log_model.update_entity(login_log)

            #更新登录时间到app_info
            app_id = self.get_app_id()
            if app_id:
                AppInfoModel(context=self).update_table("modify_date=%s", "app_id=%s", [login_log.modify_date, app_id])
        except:
            pass

        self.reponse_json_success()


class UserStatusHandler(SevenBaseHandler):
    """
    :description: 更新用户状态
    """
    @filter_check_params("userid,user_state")
    def get_async(self):
        """
        :description: 更新用户状态
        :param userid：用户id
        :param user_state：用户状态
        :return: 
        :last_editors: HuangJingCan
        """
        user_id = int(self.get_param("userid"))
        user_state = int(self.get_param("user_state"))
        modify_date = self.get_now_datetime()
        relieve_date = self.get_now_datetime()

        UserInfoModel(context=self).update_table("user_state=%s,modify_date=%s,relieve_date=%s", "id=%s", [user_state, modify_date, relieve_date, user_id])

        self.reponse_json_success()


class UserStatusByBlackHandler(SevenBaseHandler):
    """
    :description: 更新用户状态(拉黑)
    """
    @filter_check_params("userid")
    def get_async(self):
        """
        :description: 更新用户状态(拉黑)
        :param userid：用户id
        :return: 
        :last_editors: LaiKaiXiang
        """
        user_id = int(self.get_param("userid"), 0)
        modify_date = self.get_now_datetime()
        relieve_date = self.get_now_datetime()

        if user_id <= 0:
            return self.reponse_json_error("error", "找不到用户!")

        user_model = UserInfoModel(context=self)
        user_black_model = UserBlacklistModel(context=self)

        user_info = user_model.get_entity_by_id(user_id)
        if not user_info:
            return self.reponse_json_error("error", "找不到用户!")

        if user_info.user_state == 1:
            return self.reponse_json_error("error", "该用户已是黑名单!")

        user_model.update_table("user_state=1,modify_date=%s,relieve_date=%s", "id=%s", [modify_date, relieve_date, user_id])

        user_blacklist = user_black_model.get_entity("open_id=%s and act_id=%s", params=[user_info.open_id, user_info.act_id])

        if not user_blacklist:
            #添加到用户黑名单管理表
            user_blacklist = UserBlacklist()
            user_blacklist.app_id = user_info.app_id
            user_blacklist.act_id = user_info.act_id
            user_blacklist.open_id = user_info.open_id
            user_blacklist.user_nick = user_info.user_nick
            user_blacklist.black_type = 2
            user_blacklist.refund_order_data = []
            user_blacklist.create_date = self.get_now_datetime()
            user_black_model.add_entity(user_blacklist)
        else:
            user_blacklist.audit_status = 0
            user_blacklist.black_type = 2
            user_blacklist.create_date = self.get_now_datetime()
            user_black_model.update_entity(user_blacklist)

        self.reponse_json_success()


class UserListHandler(SevenBaseHandler):
    """
    :description: 用户列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 用户列表
        :param page_index:页索引
        :param page_size:页大小
        :param act_id:活动id
        :param user_nick:用户昵称
        :param open_id:open_id
        :param user_state:用户状态
        :param is_integral:是否需要用剩余积分计算剩余次数 0不需要 1需要
        :return PageInfo
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))
        act_id = int(self.get_param("act_id", 0))
        user_nick = self.get_param("nick_name")
        user_open_id = self.get_param("user_open_id")
        user_state = int(self.get_param("user_state", -1))
        is_integral = int(self.get_param("is_integral", 0))

        condition = "act_id=%s"
        params = [act_id]

        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if user_open_id:
            condition += " AND open_id=%s"
            params.append(user_open_id)
        if user_state >= 0:
            condition += " AND user_state=%s"
            params.append(user_state)

        page_list, total = UserInfoModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)

        if is_integral == 1:
            act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
            if act_dict:
                for user_info in page_list:
                    user_info['lottery_value'] = user_info['surplus_integral'] // act_dict['lottery_value']

        page_info = PageInfo(page_index, page_size, total, page_list)

        return self.reponse_json_success(page_info)


class UserListExportHandler(SevenBaseHandler):
    """
    :description: 用户列表导出
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 用户列表
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param user_nick：用户昵称
        :return PageInfo
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))
        act_id = int(self.get_param("act_id", 0))
        user_nick = self.get_param("nick_name")
        user_state = int(self.get_param("user_state", -1))

        condition = "act_id=%s"
        params = [act_id]

        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if user_state >= 0:
            condition += " AND user_state=%s"
            params.append(user_state)

        page_list, total = UserInfoModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)

        #订单奖品
        result_data = []
        for page in page_list:
            data_row = {}
            data_row["淘宝名"] = page["user_nick"]
            data_row["累计消费金额(排除退款)"] = str(page["store_pay_price"])
            data_row["剩余抽奖次数"] = str(page["lottery_sum"])
            data_row["剩余积分"] = str(page["surplus_integral"])
            data_row["创建时间"] = page["create_date"]
            if page["user_state"] == 0:
                data_row["状态"] = "正常"
            else:
                data_row["状态"] = "黑名单"

            result_data.append(data_row)

        resource_path = ""
        if result_data:
            path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
            ExcelHelper.export(result_data, path)

            resource_path = OSS2Helper().upload("", path, config.get_value("oss_folder"), False)

            os.remove(path)

        self.reponse_json_success(resource_path)


class UserBlackStatusHandler(SevenBaseHandler):
    """
    docstring 黑名单状态管理
    """
    @filter_check_params("black_id,audit_status")
    def get_async(self):
        """
        :description: 黑名单状态管理
        :param black_id：用户黑名单管理id
        :param audit_status：审核状态(0黑名单1申请中2同意3拒绝)
        :return: reponse_json_success
        :last_editors: LaiKaiXiang
        """
        black_id = int(self.get_param("black_id", 0))
        audit_status = int(self.get_param("audit_status", 0))
        audit_date = self.get_now_datetime()

        if black_id <= 0:
            return self.reponse_json_error("error", "找不到该条记录!")

        user_blacklist_model = UserBlacklistModel(context=self)
        black_info = user_blacklist_model.get_entity_by_id(black_id)
        if not black_info:
            return self.reponse_json_error("error", "找不到该条记录!")

        user_info_model = UserInfoModel(context=self)

        if audit_status == 2:
            user_blacklist_model.update_table("audit_status=%s,audit_date=%s", "id=%s", [audit_status, audit_date, black_id])
            userInfo = user_info_model.get_entity("act_id=%s and open_id=%s", params=[black_info.act_id, black_info.open_id])
            if not userInfo:
                return self.reponse_json_error("error", "找不到用户!")

            userInfo.user_state = 0
            userInfo.modify_date = audit_date
            userInfo.relieve_date = audit_date
            user_info_model.update_entity(userInfo)

        if audit_status == 0:
            user_blacklist_model.update_table("audit_status=%s,audit_date=%s,black_type=2", "id=%s", [audit_status, audit_date, black_id])
            userInfo = user_info_model.get_entity("act_id=%s and open_id=%s", params=[black_info.act_id, black_info.open_id])
            if not userInfo:
                return self.reponse_json_error("error", "找不到用户!")

            userInfo.user_state = 1
            userInfo.modify_date = audit_date
            user_info_model.update_entity(userInfo)

        if audit_status == 3:
            user_blacklist_model.update_table("audit_status=%s,audit_date=%s", "id=%s", [audit_status, audit_date, black_id])

        self.reponse_json_success()


class UserBlackListHandler(SevenBaseHandler):
    """
    获取黑名单管理列表
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 获取黑名单管理列表
        :param act_id：act_id
        :param audit_status：状态
        :param nick_name：用户昵称
        :param create_date_start：创建时间开始
        :param create_date_end：创建时间结束
        :return: list
        :last_editors: LaiKaiXiang
        """
        act_id = int(self.get_param("act_id", 0))
        audit_status = int(self.get_param("audit_status", -1))
        user_nick = self.get_param("nick_name")
        create_date_start = self.get_param("create_date_start")
        create_date_end = self.get_param("create_date_end")

        if act_id <= 0:
            return self.reponse_json_error_params()

        condition = "act_id=%s"
        params = [act_id]

        if audit_status >= 0:
            condition += " AND audit_status=%s"
            params.append(audit_status)
        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if create_date_start:
            condition += " AND create_date>=%s"
            params.append(create_date_start)
        if create_date_end:
            condition += " AND create_date<=%s"
            params.append(create_date_end)

        user_black_dict_list = UserBlacklistModel(context=self).get_dict_list(condition, order_by="create_date desc", params=params)

        for user_black in user_black_dict_list:
            user_black["refund_order_data"] = self.json_loads(user_black["refund_order_data"]) if user_black["refund_order_data"] else []

        self.reponse_json_success(user_black_dict_list)


class LotteryValueHandler(SevenBaseHandler):
    """
    :description: 设置抽奖次数或者积分
    """
    @filter_check_params("user_open_id,act_id")
    def post_async(self):
        """
        :description: 设置抽奖次数或者积分
        :param user_open_id：用户唯一标识
        :param current_value：修改的次数
        :return: reponse_json_success
        :last_editors: LaiKaiXiang
        """
        user_open_id = self.get_param("user_open_id")
        current_value = int(self.get_param("current_value", 0))
        act_id = int(self.get_param("act_id", 0))
        app_id = self.get_param("app_id")
        modify_date = self.get_now_datetime()

        if act_id <= 0:
            return self.reponse_json_error_params()
        act_dict = ActInfoModel(context=self).get_dict_by_id(act_id)
        if not act_dict:
            return self.reponse_json_error_params()

        user_info_model = UserInfoModel(context=self)
        user_info = user_info_model.get_entity("open_id=%s and act_id=%s", params=[user_open_id, act_id])
        if not user_info:
            return self.reponse_json_error_params()

        history_value = 0
        if act_dict['currency_type'] == 1:
            history_value = user_info.lottery_value
        elif act_dict['currency_type'] == 2:
            history_value = user_info.surplus_integral
        if history_value != current_value:
            update_sql = ""
            if act_dict['currency_type'] == 1:
                update_sql = "lottery_value=%s,modify_date=%s"
            if act_dict['currency_type'] == 2:
                update_sql = "surplus_integral=%s,modify_date=%s"
            if update_sql == "":
                return self.reponse_json_success()
            result = user_info_model.update_table(update_sql, "act_id=%s AND open_id=%s", [current_value, modify_date, act_id, user_open_id])
            if result:
                lottery_value_log = LotteryValueLog()
                lottery_value_log.app_id = app_id
                lottery_value_log.act_id = act_id
                lottery_value_log.open_id = user_open_id
                lottery_value_log.user_nick = user_info.user_nick
                lottery_value_log.log_title = "手动配置"
                lottery_value_log.source_type = SourceType.手动配置.value
                lottery_value_log.change_type = 301 if int(current_value - history_value) > 0 else 302
                lottery_value_log.operate_type = 0 if int(current_value - history_value) > 0 else 1
                lottery_value_log.current_value = current_value - history_value
                lottery_value_log.history_value = history_value
                lottery_value_log.log_info = {}
                lottery_value_log.create_date = self.get_now_datetime()
                LotteryValueLogModel(context=self).add_entity(lottery_value_log)

                #添加商家对帐记录
                coin_order_model = CoinOrderModel(context=self)
                if (current_value - history_value) > 0:
                    coin_order = CoinOrder()
                    coin_order.open_id = user_open_id
                    coin_order.app_id = app_id
                    coin_order.act_id = act_id
                    coin_order.reward_type = 0
                    coin_order.nick_name = user_info.user_nick
                    coin_order.buy_count = current_value - history_value
                    coin_order.surplus_count = current_value - history_value
                    coin_order.create_date = self.get_now_datetime()
                    coin_order.modify_date = self.get_now_datetime()
                    coin_order_model.add_entity(coin_order)
                else:
                    del_count = history_value - current_value
                    update_coin_order_list = []
                    coin_order_set_list = coin_order_model.get_list("act_id=%s and open_id=%s and surplus_count>0 and pay_order_id=0", "id asc", params=[act_id, user_open_id])

                    if len(coin_order_set_list) > 0:
                        for coin_order in coin_order_set_list:
                            if coin_order.surplus_count > del_count:
                                coin_order.surplus_count = coin_order.surplus_count - del_count
                                del_count = 0
                            else:
                                del_count = del_count - coin_order.surplus_count
                                coin_order.surplus_count = 0
                            update_coin_order_list.append(coin_order)
                            if del_count == 0:
                                break
                    if del_count > 0:
                        coin_order_pay_list = coin_order_model.get_list("act_id=%s and open_id=%s and surplus_count>0 and pay_order_id>0", "id asc", params=[act_id, user_open_id])
                        if len(coin_order_pay_list) > 0:
                            for coin_order in coin_order_pay_list:
                                if coin_order.surplus_count > del_count:
                                    coin_order.surplus_count = coin_order.surplus_count - del_count
                                    del_count = 0
                                else:
                                    del_count = del_count - coin_order.surplus_count
                                    coin_order.surplus_count = 0
                                update_coin_order_list.append(coin_order)
                                if del_count == 0:
                                    break
                    for coin_order in update_coin_order_list:
                        coin_order_model.update_entity(coin_order)

        self.reponse_json_success()


class LotteryValueLogHandler(SevenBaseHandler):
    """
    :description: 用户抽奖配置记录
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 用户抽奖配置记录
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param nick_name：淘宝名
        :param start_date：开始时间
        :param end_date：结束时间
        :param source_type：来源类型
        :param user_open_id：用户open_id
        :return list
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))
        act_id = int(self.get_param("act_id", 0))
        user_nick = self.get_param("nick_name")
        start_date = self.get_param("start_date")
        end_date = self.get_param("end_date")
        source_type = int(self.get_param("source_type", -1))
        user_open_id = self.get_param("user_open_id")

        condition = "act_id=%s"
        params = [act_id]

        if source_type >= 0:
            condition += " AND source_type=%s"
            params.append(source_type)
        if user_open_id:
            condition += " AND open_id=%s"
            params.append(user_open_id)
        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if start_date:
            condition += " AND create_date>=%s"
            params.append(start_date)
        if end_date:
            condition += " AND create_date<=%s"
            params.append(end_date)

        page_list, total = LotteryValueLogModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        self.reponse_json_success(page_info)


class LotteryValueLogExportHandler(SevenBaseHandler):
    """
    :description: 用户积分记录导出
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 用户积分记录导出
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param nick_name：淘宝名
        :param start_date：开始时间
        :param end_date：结束时间
        :return list
        :last_editors: HuangJingCan
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))
        act_id = int(self.get_param("act_id", 0))
        user_nick = self.get_param("nick_name")
        start_date = self.get_param("start_date")
        end_date = self.get_param("end_date")

        condition = "act_id=%s"
        params = [act_id]

        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if start_date:
            condition += " AND create_date>=%s"
            params.append(start_date)
        if end_date:
            condition += " AND create_date<=%s"
            params.append(end_date)

        page_list, total = LotteryValueLogModel(context=self).get_dict_page_list("*", page_index, page_size, condition, order_by="id desc", params=params)

        result_data = []
        for page in page_list:
            data_row = {}
            data_row["淘宝名"] = page["user_nick"]
            data_row["变动原因"] = page["log_title"]
            data_row["变动时间"] = page["create_date"]
            data_row["变动值"] = str(page["current_value"])
            data_row["备注"] = page["log_desc"]

            result_data.append(data_row)

        resource_path = ""
        if result_data:
            path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
            ExcelHelper.export(result_data, path)

            resource_path = OSS2Helper().upload("", path, config.get_value("oss_folder"), False)

            os.remove(path)

        self.reponse_json_success(resource_path)


class UserDetailHandler(SevenBaseHandler):
    """
    :description:  用户详情(道具数量)   
    """
    @filter_check_params("user_open_id,act_id")
    def get_async(self):
        """
        :description: 用户详情
        :param user_open_id：用户唯一标识
        :return: reponse_json_success
        :last_editors: HuangJianYi
        """
        user_open_id = self.get_param("user_open_id")
        act_id = int(self.get_param("act_id", 0))

        condition = "act_id=%s and open_id=%s"
        params = [act_id, user_open_id]

        user_detail_model = UserDetailModel(context=self)
        user_detail = user_detail_model.get_entity(condition, params=params)

        if not user_detail:
            user_detail = UserDetail()
            user_detail.tips_card_count = 0
            user_detail.perspective_card_count = 0
            user_detail.redraw_card_count = 0

        return self.reponse_json_success(user_detail)


class PropLogHandler(SevenBaseHandler):
    """
    :description: 道具数量变动明细记录
    """
    @filter_check_params("act_id")
    def get_async(self):
        """
        :description: 道具数量变动明细记录
        :param page_index：页索引
        :param page_size：页大小
        :param act_id：活动id
        :param nick_name：淘宝名
        :param start_date：开始时间
        :param end_date：结束时间
        :param user_open_id：用户open_id
        :return list
        :last_editors: HuangJianYi
        """
        page_index = int(self.get_param("page_index", 0))
        page_size = int(self.get_param("page_size", 20))
        act_id = int(self.get_param("act_id", 0))
        change_type = int(self.get_param("change_type", 0))
        user_nick = self.get_param("nick_name")
        start_date = self.get_param("start_date")
        end_date = self.get_param("end_date")
        user_open_id = self.get_param("user_open_id")

        condition = "act_id=%s"
        params = [act_id]
        field = "user_nick,change_type,operate_type,prop_type,machine_name,specs_type,operate_value,history_value,title,create_date"

        if user_open_id:
            condition += " AND open_id=%s"
            params.append(user_open_id)
        if user_nick:
            condition += " AND user_nick=%s"
            params.append(user_nick)
        if start_date:
            condition += " AND create_date>=%s"
            params.append(start_date)
        if end_date:
            condition += " AND create_date<=%s"
            params.append(end_date)
        if change_type > 0:
            condition += " AND change_type=%s"
            params.append(change_type)

        page_list, total = PropLogModel(context=self).get_dict_page_list(field, page_index, page_size, condition, order_by="id desc", params=params)

        page_info = PageInfo(page_index, page_size, total, page_list)

        self.reponse_json_success(page_info)